@@ -426,7 +426,7 @@ JU.Logger.debug("setModulation iop = " + iop + " " + this.symmetry.getSpaceGroup
 }var ms =  new JU.ModulationSet().setMod(a.index + " " + a.atomName, this.getAtomR0(this.cr.asc.atoms[a.atomSite]), this.getAtomR0(a), this.modDim, list, this.gammaE, this.getMatrices(a), this.getSymmetry(a), this.nOps, iop, Clazz.instanceOf(a.vib,"JU.Vibration") ? a.vib : null, this.isCommensurate);
 ms.calculate(this.modTUV, false);
 if (!Float.isNaN(ms.vOcc)) {
-a.foccupancy = ms.setOccupancy(this.getMod("J_O#0;" + a.atomName), a.foccupancy, (a.vib == null ? 0 : a.vib.x));
+a.foccupancy = ms.setOccupancy(this.getMod("J_O#0;" + a.atomName), a.foccupancy, a.getMult());
 }if (ms.htUij != null) {
 var t = (a.tensors == null ? null : a.tensors.get(0));
 if (t != null && t.parBorU != null) {
@@ -593,4 +593,4 @@ if (a != null) lattvecs.addLast(a);
 return true;
 }, "JU.Lst,~S");
 });
-;//5.0.1-v7 Sat Jan 10 12:43:18 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:07:02 CST 2026
