@@ -1,5 +1,5 @@
 Clazz.declarePackage("J.adapter.readers.pdb");
-Clazz.load(["J.adapter.readers.pdb.PdbReader"], "J.adapter.readers.pdb.JmolDataReader", ["java.util.Hashtable", "JU.P3", "$.PT", "JS.T", "JU.C", "$.Escape", "$.Logger", "$.Parser", "$.Vibration"], function(){
+Clazz.load(["J.adapter.readers.pdb.PdbReader"], "J.adapter.readers.pdb.JmolDataReader", ["java.util.Hashtable", "JU.Lst", "$.P3", "$.PT", "JS.T", "JU.C", "$.Escape", "$.Logger", "$.Parser", "$.Vibration"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.props = null;
 this.residueNames = null;
@@ -234,5 +234,33 @@ mdata.uvw0[1].scale(105);
 mdata.uvw0[2].scale(105);
 mdata.uvw =  Clazz.newArray(-1, [JU.P3.newP(mdata.uvw0[0]), JU.P3.newP(mdata.uvw0[1]), JU.P3.newP(mdata.uvw0[2])]);
 }}}, "JM.ModelSet,~S,~N,~N");
+Clazz.defineMethod(c$, "getPlotSpinSet", 
+function(vwr, bs, modelIndex, minXYZ, maxXYZ){
+if (bs.nextSetBit(0) < 0) {
+bs = vwr.getModelUndeletedAtomsBitSet(modelIndex);
+}if (bs.isEmpty()) return null;
+var len = 0;
+for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
+var v = vwr.ms.getVibration(i, false);
+if (v == null) bs.clear(i);
+ else len = Math.max(len, v.length());
+}
+if (len == 0) return null;
+minXYZ.set(-len, -len, -len);
+maxXYZ.set(len, len, len);
+var lst =  new JU.Lst();
+for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
+var v = vwr.ms.getVibration(i, false);
+var found = false;
+for (var j = lst.size(); --j >= 0; ) {
+if (v.distance(lst.get(j)) < 0.1) {
+found = true;
+bs.clear(i);
+break;
+}}
+if (!found) lst.addLast(v);
+}
+return bs;
+}, "JV.Viewer,JU.BS,~N,JU.P3,JU.P3");
 });
-;//5.0.1-v7 Sat Jan 10 13:10:19 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
