@@ -13,4 +13,4 @@ atom.partialCharge = this.parseFloatStr(tokens[pt++]);
 atom.radius = J.adapter.readers.pdb.PdbReader.fixRadius(this.parseFloatStr(tokens[pt]));
 }}, "J.adapter.smarter.Atom");
 });
-;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
+;//5.0.1-v7 Tue Jan 27 20:35:35 CST 2026
