@@ -1290,4 +1290,4 @@ this.jmolToUniqueID =  Clazz.newIntArray (nAtomsJmol, 0);
 }, "~N");
 c$.MEAS_DIGITS =  Clazz.newIntArray(-1, [530, 531, 532]);
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
