@@ -170,4 +170,4 @@ if (f == null) JU.Logger.error("Exponent for " + code + " not found");
 return  new J.quantum.SlaterData(iAtom, x, y, z, r, zeta, 1);
 }, "~N,~S,~S");
 });
-;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
+;//5.0.1-v7 Tue Jan 27 20:35:35 CST 2026
