@@ -434,4 +434,4 @@ this.asc.setAtomProperties("J", data, this.asc.iSet, false);
 this.appendLoadNote("NMR J Couplings saved for model=" + (this.asc.iSet + 1) + " as property_J;\n use set measurementUnits \"+hz\" to measure them.");
 }});
 });
-;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
+;//5.0.1-v7 Tue Jan 27 20:35:35 CST 2026
