@@ -396,4 +396,4 @@ if (charge != 0) name += "<sup>" + Math.abs(charge) + (charge > 0 ? "+" : charge
 }return name;
 }, "JM.Atom");
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
