@@ -115,4 +115,4 @@ return;
 }}, "~S");
 c$.keepCharsList =  Clazz.newArray(-1, ["name", "x", "y", "z", "formalchg", "atomkey", "atsym", "e00", "e01", "e02", "e03", "e10", "e11", "e12", "e13", "e20", "e21", "e22", "e23", "e30", "e31", "e32", "e33"]);
 });
-;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
+;//5.0.1-v7 Tue Jan 27 20:35:35 CST 2026
