@@ -104,4 +104,4 @@ for (var i = 0; i < this.nAtom; i++) atoms[i + i0].elementNumber = Clazz.floatTo
 this.applySymmetry();
 });
 });
-;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
+;//5.0.1-v7 Tue Jan 27 20:35:35 CST 2026
