@@ -809,4 +809,4 @@ return false;
 c$.crtypes =  Clazz.newArray(-1, ["??", "nuclei", "bonds", "rings", "cages"]);
 c$.smap =  Clazz.newIntArray(-1, [2, 3, 4, 11, 5, 6, 7, 12, 8, 9, 10, 13]);
 });
-;//5.0.1-v7 Sat Jan 10 12:06:19 CST 2026
+;//5.0.1-v7 Tue Jan 27 20:35:35 CST 2026
