@@ -437,4 +437,4 @@ m4.invert();
 }return JS.SymmetryOperation.getTransformABC(m4, false);
 }, "JU.M4");
 });
-;//5.0.1-v7 Sat Jan 10 12:43:18 CST 2026
+;//5.0.1-v7 Tue Jan 27 20:35:35 CST 2026
