@@ -559,4 +559,4 @@ this.ms.addModulation(null, key, this.setRigidBodyPhase(key,  Clazz.newDoubleArr
 }, "~S,~N,~N");
 c$.XYZ =  Clazz.newArray(-1, ["x", "y", "z"]);
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Tue Jan 27 20:35:35 CST 2026
