@@ -211,4 +211,4 @@ if (!this.haveMagnetic && this.asc.ac > 0) {
 this.setProperties("pwm_magnetic",  Clazz.newFloatArray (this.asc.ac, 0), this.nAtoms);
 }});
 });
-;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
+;//5.0.1-v7 Tue Jan 27 20:35:35 CST 2026
