@@ -72,7 +72,7 @@ return (this.atom.vib == null || Float.isNaN(this.atom.vib.z) ? null : this.atom
 });
 Clazz.overrideMethod(c$, "getSeqID", 
 function(){
-return (this.atom.vib == null || !Float.isNaN(this.atom.vib.y) || this.atom.vib.z != 1094713368 ? 0 : Clazz.floatToInt(this.atom.vib.x));
+return ((this.atom.seqIdOrWyckoffCode & (-2147483648)) == (-2147483648) ? this.atom.seqIdOrWyckoffCode & 2147483647 : 0);
 });
 Clazz.overrideMethod(c$, "getBfactor", 
 function(){
@@ -127,4 +127,4 @@ function(){
 return this.atom.part;
 });
 });
-;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
