@@ -31,12 +31,8 @@ this.noSymmetryCount = 0;
 this.packingRange = 0;
 this.ptOffset = null;
 this.ptTemp = null;
-this.rminx = 0;
-this.rminy = 0;
-this.rminz = 0;
-this.rmaxx = 0;
-this.rmaxy = 0;
-this.rmaxz = 0;
+this.rmin = null;
+this.rmax = null;
 this.symmetry = null;
 this.symmetryRange = 0;
 this.trajectoryUnitCells = null;
@@ -377,45 +373,7 @@ a.anisoBorU = null;
 });
 Clazz.defineMethod(c$, "adjustRangeMinMax", 
 function(oabc){
-var pa =  new JU.P3();
-var pb =  new JU.P3();
-var pc =  new JU.P3();
-if (this.acr.forcePacked) {
-pa.setT(oabc[1]);
-pb.setT(oabc[2]);
-pc.setT(oabc[3]);
-pa.scale(this.packingRange);
-pb.scale(this.packingRange);
-pc.scale(this.packingRange);
-}oabc[0].scaleAdd2(this.minXYZ.x, oabc[1], oabc[0]);
-oabc[0].scaleAdd2(this.minXYZ.y, oabc[2], oabc[0]);
-oabc[0].scaleAdd2(this.minXYZ.z, oabc[3], oabc[0]);
-oabc[0].sub(pa);
-oabc[0].sub(pb);
-oabc[0].sub(pc);
-var pt = JU.P3.newP(oabc[0]);
-this.symmetry.toFractional(pt, true);
-this.setSymmetryMinMax(pt);
-oabc[1].scale(this.maxXYZ.x - this.minXYZ.x);
-oabc[2].scale(this.maxXYZ.y - this.minXYZ.y);
-oabc[3].scale(this.maxXYZ.z - this.minXYZ.z);
-oabc[1].scaleAdd2(2, pa, oabc[1]);
-oabc[2].scaleAdd2(2, pb, oabc[2]);
-oabc[3].scaleAdd2(2, pc, oabc[3]);
-for (var i = 0; i < 3; i++) {
-for (var j = i + 1; j < 4; j++) {
-pt.add2(oabc[i], oabc[j]);
-if (i != 0) pt.add(oabc[0]);
-this.symmetry.toFractional(pt, false);
-this.setSymmetryMinMax(pt);
-}
-}
-this.symmetry.toCartesian(pt, false);
-pt.add(oabc[1]);
-this.symmetry.toFractional(pt, false);
-this.setSymmetryMinMax(pt);
-this.minXYZ = JU.P3i.new3(Clazz.doubleToInt(Math.min(0, Math.floor(this.rminx + 0.001))), Clazz.doubleToInt(Math.min(0, Math.floor(this.rminy + 0.001))), Clazz.doubleToInt(Math.min(0, Math.floor(this.rminz + 0.001))));
-this.maxXYZ = JU.P3i.new3(Clazz.doubleToInt(Math.max(1, Math.ceil(this.rmaxx - 0.001))), Clazz.doubleToInt(Math.max(1, Math.ceil(this.rmaxy - 0.001))), Clazz.doubleToInt(Math.max(1, Math.ceil(this.rmaxz - 0.001))));
+this.symmetry.adjustRangeMinMax(oabc, (this.acr.forcePacked ? this.packingRange : NaN), this.minXYZ, this.maxXYZ, this.rmin, this.rmax, this.minXYZ, this.maxXYZ);
 }, "~A");
 Clazz.defineMethod(c$, "applyAllSymmetry", 
 function(ms, bsAtoms){
@@ -468,8 +426,8 @@ var checkCartesianRange = (this.symmetryRange != 0);
 var checkRangeNoSymmetry = (this.symmetryRange < 0);
 var checkRange111 = (this.symmetryRange > 0);
 if (checkCartesianRange) {
-this.rminx = this.rminy = this.rminz = 3.4028235E38;
-this.rmaxx = this.rmaxy = this.rmaxz = -3.4028235E38;
+this.rmin.x = this.rmin.y = this.rmin.z = 3.4028235E38;
+this.rmax.x = this.rmax.y = this.rmax.z = -3.4028235E38;
 }var sym = this.symmetry;
 var lastSymmetry = sym;
 this.checkAll = (this.crystalReaderLatticeOpsOnly || this.asc.atomSetCount == 1 && this.checkNearAtoms && this.latticeOp >= 0);
@@ -528,27 +486,27 @@ continue;
 }}if (bsAtoms != null) atom.bsSymmetry.clearAll();
 atom.bsSymmetry.set(iCell * operationCount);
 atom.bsSymmetry.set(0);
-if (checkCartesianRange) this.setSymmetryMinMax(c);
+if (checkCartesianRange) JS.UnitCell.setSymmetryMinMax(c, this.rmin, this.rmax);
 if (pt < cartesianCount) cartesians[pt] = c;
 }
 if (checkRangeNoSymmetry) {
-this.rminx -= absRange;
-this.rminy -= absRange;
-this.rminz -= absRange;
-this.rmaxx += absRange;
-this.rmaxy += absRange;
-this.rmaxz += absRange;
+this.rmin.x -= absRange;
+this.rmin.y -= absRange;
+this.rmin.z -= absRange;
+this.rmax.x += absRange;
+this.rmax.y += absRange;
+this.rmax.z += absRange;
 }cell555Count = pt = this.symmetryAddAtoms(0, 0, 0, 0, pt, iCell * operationCount, cartesians, ms, excludedOps, atomMap);
 }
 }
 }
 if (checkRange111) {
-this.rminx -= absRange;
-this.rminy -= absRange;
-this.rminz -= absRange;
-this.rmaxx += absRange;
-this.rmaxy += absRange;
-this.rmaxz += absRange;
+this.rmin.x -= absRange;
+this.rmin.y -= absRange;
+this.rmin.z -= absRange;
+this.rmax.x += absRange;
+this.rmax.y += absRange;
+this.rmax.z += absRange;
 }iCell = 0;
 for (var tx = this.minXYZ.x; tx < this.maxXYZ.x; tx++) {
 for (var ty = this.minXYZ.y; ty < this.maxXYZ.y; ty++) {
@@ -585,7 +543,7 @@ for (var i = this.asc.ac; --i >= this.firstAtom; ) {
 pt0.setT(atoms[i]);
 this.symmetry.toCartesian(pt0, false);
 superSymmetry.toFractional(pt0, false);
-if (this.acr.noPack ? !this.removePacking(this.ndims, pt0, minXYZ2.x, maxXYZ2.x, minXYZ2.y, maxXYZ2.y, minXYZ2.z, maxXYZ2.z, this.packingRange) : !this.isWithinCell(this.ndims, pt0, minXYZ2.x, maxXYZ2.x, minXYZ2.y, maxXYZ2.y, minXYZ2.z, maxXYZ2.z, this.packingRange)) bsAtoms.clear(i);
+if (this.acr.noPack ? !J.adapter.smarter.XtalSymmetry.removePacking(this.ndims, pt0, minXYZ2.x, maxXYZ2.x, minXYZ2.y, maxXYZ2.y, minXYZ2.z, maxXYZ2.z, this.packingRange) : !this.isWithinCell(this.ndims, pt0, minXYZ2.x, maxXYZ2.x, minXYZ2.y, maxXYZ2.y, minXYZ2.z, maxXYZ2.z, this.packingRange)) bsAtoms.clear(i);
 }
 }, "JU.BS");
 Clazz.defineMethod(c$, "applySuperSymmetry", 
@@ -633,8 +591,8 @@ var bsAtoms = this.asc.bsAtoms;
 if (bsAtoms != null) {
 this.updateBSAtoms();
 this.firstAtom = bsAtoms.nextSetBit(this.firstAtom);
-}this.rminx = this.rminy = this.rminz = 3.4028235E38;
-this.rmaxx = this.rmaxy = this.rmaxz = -3.4028235E38;
+}this.rmin = JU.P3.new3(3.4028235E38, 3.4028235E38, 3.4028235E38);
+this.rmax = JU.P3.new3(-3.4028235E38, -3.4028235E38, -3.4028235E38);
 if (this.acr.latticeType == null) this.acr.latticeType = "" + this.symmetry.getLatticeType();
 if (this.acr.isPrimitive) {
 this.asc.setCurrentModelInfo("isprimitive", Boolean.TRUE);
@@ -682,7 +640,7 @@ vabc[2] = JU.V3.newV(oabc[3]);
 this.adjustRangeMinMax(oabc);
 }}var iAtomFirst = this.asc.getLastAtomSetAtomIndex();
 if (bsAtoms != null) iAtomFirst = bsAtoms.nextSetBit(iAtomFirst);
-if (this.rminx == 3.4028235E38) {
+if (this.rmin.x == 3.4028235E38) {
 supercell = null;
 oabc = null;
 } else {
@@ -729,7 +687,7 @@ if (symmetry.fixUnitCell(this.acr.unitCellParams)) {
 this.acr.appendLoadNote("Unit cell parameters were adjusted to match space group!");
 }this.setUnitCellSafely();
 }, "J.adapter.smarter.XtalSymmetry.FileSymmetry");
-Clazz.defineMethod(c$, "removePacking", 
+c$.removePacking = Clazz.defineMethod(c$, "removePacking", 
 function(ndims, pt, minX, maxX, minY, maxY, minZ, maxZ, slop){
 return (pt.x > minX - slop && pt.x < maxX - slop && (ndims < 2 || pt.y > minY - slop && pt.y < maxY - slop) && (ndims < 3 || pt.z > minZ - slop && pt.z < maxZ - slop));
 }, "~N,JU.P3,~N,~N,~N,~N,~N,~N,~N");
@@ -827,15 +785,6 @@ this.minXYZ =  new JU.P3i();
 this.maxXYZ = JU.P3i.new3(maxX, maxY, maxZ);
 JU.SimpleUnitCell.setMinMaxLatticeParameters(dim, this.minXYZ, this.maxXYZ, kcode);
 }, "~N,~N,~N,~N,~N");
-Clazz.defineMethod(c$, "setSymmetryMinMax", 
-function(c){
-if (this.rminx > c.x) this.rminx = c.x;
-if (this.rminy > c.y) this.rminy = c.y;
-if (this.rminz > c.z) this.rminz = c.z;
-if (this.rmaxx < c.x) this.rmaxx = c.x;
-if (this.rmaxy < c.y) this.rmaxy = c.y;
-if (this.rmaxz < c.z) this.rmaxz = c.z;
-}, "JU.P3");
 Clazz.defineMethod(c$, "setUnitCell", 
 function(info, matUnitCellOrientation, unitCellOffset){
 this.unitCellParams =  Clazz.newFloatArray (info.length, 0);
@@ -918,10 +867,10 @@ sym.toFractional(pttemp, false);
 this.acr.fixFloatPt(pttemp, 100000.0);
 if (!this.isWithinCell(this.ndims, pttemp, this.minXYZ0.x, this.maxXYZ0.x, this.minXYZ0.y, this.maxXYZ0.y, this.minXYZ0.z, this.maxXYZ0.z, this.packingRange)) {
 continue;
-}}if (checkSymmetryMinMax) this.setSymmetryMinMax(c);
+}}if (checkSymmetryMinMax) JS.UnitCell.setSymmetryMinMax(c, this.rmin, this.rmax);
 var special = null;
 if (checkDistance) {
-if (checkSymmetryRange && (c.x < this.rminx || c.y < this.rminy || c.z < this.rminz || c.x > this.rmaxx || c.y > this.rmaxy || c.z > this.rmaxz)) continue;
+if (checkSymmetryRange && (c.x < this.rmin.x || c.y < this.rmin.y || c.z < this.rmin.z || c.x > this.rmax.x || c.y > this.rmax.y || c.z > this.rmax.z)) continue;
 var minDist2 = 3.4028235E38;
 var j0 = (this.checkAll ? this.asc.ac : pt0);
 var name = a.atomName;
@@ -1024,7 +973,7 @@ var atoms = this.asc.atoms;
 var bs = this.updateBSAtoms();
 if (this.acr.noPack) {
 for (var i = bs.nextSetBit(iAtomFirst); i >= 0; i = bs.nextSetBit(i + 1)) {
-if (!this.removePacking(this.ndims, atoms[i], this.minXYZ.x, this.maxXYZ.x, this.minXYZ.y, this.maxXYZ.y, this.minXYZ.z, this.maxXYZ.z, this.packingRange)) bs.clear(i);
+if (!J.adapter.smarter.XtalSymmetry.removePacking(this.ndims, atoms[i], this.minXYZ.x, this.maxXYZ.x, this.minXYZ.y, this.maxXYZ.y, this.minXYZ.z, this.maxXYZ.z, this.packingRange)) bs.clear(i);
 }
 } else {
 for (var i = bs.nextSetBit(iAtomFirst); i >= 0; i = bs.nextSetBit(i + 1)) {
@@ -1299,4 +1248,4 @@ return this.nSpins;
 }, "J.adapter.smarter.AtomSetCollection,~B");
 /*eoif3*/})();
 });
-;//5.0.1-v7 Sat Jan 10 12:43:18 CST 2026
+;//5.0.1-v7 Tue Jan 27 20:35:35 CST 2026
