@@ -2,4 +2,4 @@ Clazz.declarePackage("J.api");
 (function(){
 var c$ = Clazz.declareType(J.api, "JmolAdapterStructureIterator", null);
 })();
-;//5.0.1-v7 Thu Dec 18 09:19:10 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
