@@ -1,3 +1,3 @@
 Clazz.declarePackage("J.api");
 Clazz.declareInterface(J.api, "JmolFilesReaderInterface", Runnable);
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:58:39 CST 2026
