@@ -1,3 +1,3 @@
 Clazz.declarePackage("J.api");
 Clazz.declareInterface(J.api, "JmolModulationSet");
-;//5.0.1-v7 Sat Jan 10 12:43:18 CST 2026
+;//5.0.1-v7 Mon Jan 19 17:29:34 CST 2026
