@@ -50,4 +50,4 @@ function(vwr, title, imageMap){
 return J.awtjs2d.Platform.Jmol().consoleGetImageDialog(vwr, title, imageMap);
 }, "JV.Viewer,~S,java.util.Map");
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:49:55 CST 2026
