@@ -242,4 +242,4 @@ if (!this.haveMacros) this.writeMacros2();
 this.output("r(" + this.getTriad(ptA) + "," + this.getTriad(ptB) + "," + this.getTriad(ptC) + "," + this.color4(colix) + ")\n");
 }, "JU.T3,JU.T3,JU.T3,~N");
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:49:55 CST 2026
