@@ -228,4 +228,4 @@ Clazz.overrideMethod(c$, "plotText",
 function(x, y, z, colix, text, font3d){
 }, "~N,~N,~N,~N,~S,JU.Font");
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Mon Jan 19 20:38:07 CST 2026
