@@ -328,4 +328,4 @@ this.gdata.plotText(x, y, z, this.gdata.getColorArgbOrGray(colix), 0, text, font
 this.outputComment("end text " + this.nText + ": " + text);
 }, "~N,~N,~N,~N,~S,JU.Font");
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
