@@ -17,4 +17,4 @@ this.g.pbufT[offset] = p & this.g.translucencyMask;
 this.pb[offset] = J.g3d.Graphics3D.mergeBufferPixel(this.pb[offset], p & this.g.translucencyMask, this.g.bgcolor);
 }}, "~N,~N,~N");
 });
-;//5.0.1-v7 Thu Dec 18 09:19:10 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
