@@ -8,4 +8,4 @@ function(vwr, files, width, height, fps, fileName){
 return this.errorMsg;
 }, "JV.Viewer,~A,~N,~N,~N,~S");
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:49:55 CST 2026
