@@ -385,4 +385,4 @@ return s;
 }, "java.io.File");
 c$.inchiVersionInternal = null;
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Mon Jan 19 20:38:07 CST 2026
