@@ -180,4 +180,4 @@ $.getScript(J2S.inchiPath +   "/inchi-web-SwingJS.js");
 }} catch (t) {
 }
 }});
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:49:55 CST 2026
