@@ -290,4 +290,4 @@ return this.b$["J.inchi.InchiToSmilesConverter"].isInchiOpposite(this.getIndex()
 /*eoif5*/})();
 };
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:53:24 CST 2026
