@@ -105,4 +105,4 @@ this.params.cutoff = -1.0;
 JU.Logger.info("MapReader: setting cutoff to default value of " + this.params.cutoff + (this.boundingBox == null ? " (no BOUNDBOX parameter)\n" : "\n"));
 }});
 });
-;//5.0.1-v7 Wed Dec 31 14:51:59 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
