@@ -59,4 +59,4 @@ this.voxelData = null;
 if (this.dataMin > this.params.cutoff) this.params.cutoff = 2 * this.dataMin;
 }, "~B");
 });
-;//5.0.1-v7 Thu Dec 18 09:19:10 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
