@@ -37,4 +37,4 @@ this.volumetricVectors[1].set(0, (ymax - ymin) / this.nPointsY, 0);
 this.volumetricVectors[2].set((zmax - zmin) / this.nPointsZ, 0, 0);
 });
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:49:55 CST 2026
