@@ -202,4 +202,4 @@ function(){
 return (this.isBinary ? this.binarydoc.readFloat() : this.parseFloatStr(this.nextToken()));
 });
 });
-;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:58:39 CST 2026
