@@ -124,4 +124,4 @@ JU.Logger.info("PyMOLMeshReader rmsd=" + rmsd + " mean=" + mean);
 return this.params.sigma * rmsd + mean;
 });
 });
-;//5.0.1-v7 Thu Dec 18 09:19:10 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
