@@ -408,4 +408,4 @@ this.voxelCounts[2] = n;
 this.params.insideOut = !this.params.insideOut;
 });
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:49:55 CST 2026
