@@ -1,5 +1,5 @@
 Clazz.declarePackage("J.modelkit");
-Clazz.load(["JU.Vibration", "JU.BS", "$.P3", "$.P4", "J.i18n.GT"], "J.modelkit.ModelKit", ["java.util.Arrays", "$.Hashtable", "$.TreeMap", "JU.Lst", "$.M4", "$.Measure", "$.PT", "$.Quat", "$.SB", "$.V3", "J.atomdata.RadiusData", "JU.BSUtil", "$.Edge", "$.Elements", "$.Logger", "$.Point3fi", "$.SimpleUnitCell", "JV.JC"], function(){
+Clazz.load(["JU.Vibration", "JU.BS", "$.P3", "$.P4", "J.i18n.GT"], "J.modelkit.ModelKit", ["java.util.Arrays", "$.Hashtable", "$.TreeMap", "JU.Lst", "$.M4", "$.Measure", "$.P3i", "$.PT", "$.Quat", "$.SB", "$.V3", "J.atomdata.RadiusData", "JU.BSUtil", "$.Edge", "$.Elements", "$.Logger", "$.Point3fi", "$.SimpleUnitCell", "JV.JC"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.vwr = null;
 this.menu = null;
@@ -271,7 +271,7 @@ if (n > 0) this.vwr.setPickingMode("dragAtom", 0);
 }, "~N,~S,JU.P3");
 Clazz.defineMethod(c$, "cmdAssignAddAtoms", 
 function(type, pts, bsAtoms, packing, cmd){
-if (type.startsWith("_")) type = type.substring(1);
+if (type != null && type.startsWith("_")) type = type.substring(1);
 return Math.abs(this.addAtomType(type, pts, bsAtoms, null, packing, cmd));
 }, "~S,~A,JU.BS,~N,~S");
 Clazz.defineMethod(c$, "cmdAssignAtom", 
@@ -318,6 +318,21 @@ throw e;
 this.setMKState(state);
 }
 }, "~N,~N,~S,~S");
+Clazz.defineMethod(c$, "cmdAssignSpaceGroup", 
+function(transform, sb, cmd, packing, doDraw){
+this.clearAtomConstraints();
+if (packing >= 0) {
+var n;
+if (doDraw) {
+n = this.cmdAssignAddAtoms("N:G", null, null, packing, cmd);
+} else {
+var bsModelAtoms = this.vwr.getThisModelAtoms();
+n = this.packAssignedSpaceGroup(null, bsModelAtoms, transform, packing, null, cmd);
+}sb.append("\n").append(J.i18n.GT.i(J.i18n.GT.$("{0} atoms added"), n));
+}if (doDraw) {
+var s = this.drawSymmetry("sg", false, -1, null, 2147483647, null, null, null, 0, -2, 0, null, true);
+this.appRunScript(s);
+}}, "~S,JU.SB,~S,~N,~B");
 Clazz.defineMethod(c$, "cmdAssignDeleteAtoms", 
 function(bs){
 this.clearAtomConstraints();
@@ -327,11 +342,35 @@ if (!bs.isEmpty()) {
 this.vwr.deleteAtoms(bs, false);
 }return bs.cardinality();
 }, "JU.BS");
+Clazz.defineMethod(c$, "cmdPackUnitCell", 
+function(sym, bsAtoms, packing){
+this.packAssignedSpaceGroup(sym, bsAtoms, null, packing, null, "packUC");
+}, "J.api.SymmetryInterface,JU.BS,~N");
+Clazz.defineMethod(c$, "cmdFillOABC", 
+function(oabc, packing, cmd){
+var bsAtoms = this.vwr.getThisModelAtoms();
+var n0 = bsAtoms.cardinality();
+if (n0 == 0) return 0;
+var uc = this.vwr.getSymTemp().getUnitCell(oabc, false, "fill");
+var min =  new JU.P3i();
+var max =  new JU.P3i();
+var sym0 = this.vwr.getOperativeSymmetry();
+sym0.adjustRangeMinMax(oabc, packing, null, null, null, null, min, max);
+var p =  new JU.P3();
+for (var i = min.x; i < max.x; i++) {
+for (var j = min.y; j < max.y; j++) {
+for (var k = min.z; k < max.z; k++) {
+p.set(i, j, k);
+sym0.setOffsetPt(p);
+this.packAssignedSpaceGroup(sym0, bsAtoms, null, packing, uc, cmd);
+}
+}
+}
+p.set(0, 0, 0);
+sym0.setOffsetPt(p);
+return this.vwr.getThisModelAtoms().cardinality() - n0;
+}, "~A,~N,~S");
 Clazz.defineMethod(c$, "cmdAssignMoveAtoms", 
-function(bsSelected, iatom, p, pts, allowProjection, isMolecule){
-return this.assignMoveAtoms(bsSelected, iatom, p, pts, allowProjection, isMolecule, true);
-}, "JU.BS,~N,JU.P3,~A,~B,~B");
-Clazz.defineMethod(c$, "assignMoveAtoms", 
 function(bsSelected, iatom, p, pts, allowProjection, isMolecule, isCommand){
 var sym = this.getSym(iatom);
 var n;
@@ -951,15 +990,15 @@ var opt = allPts.length - 1;
 for (var i = 0, ept = opt * 2; i < allPts.length; i++, ept -= 2) {
 pts[0] = allPts[i];
 var el = (i == 0 ? type : elements.substring(ept, ept + 2).trim());
-n += this.addAtoms(el, pts, bsAtoms, opsCtr, packing, cmd);
+n += this.addAtoms(el, pts, bsAtoms, opsCtr, packing, null, cmd);
 }
 return n;
 }if (!(Clazz.instanceOf(o,"JU.P3"))) return 0;
 pts =  Clazz.newArray(-1, [o]);
-}}return this.addAtoms(type, pts, bsAtoms, opsCtr, packing, cmd);
+}}return this.addAtoms(type, pts, bsAtoms, opsCtr, packing, null, cmd);
 }, "~S,~A,JU.BS,~A,~N,~S");
 Clazz.defineMethod(c$, "addAtoms", 
-function(type, pts, bsAtoms, opsCtr, packing, cmd){
+function(type, pts, bsAtoms, opsCtr, packing, uc, cmd){
 try {
 this.vwr.pushHoldRepaintWhy("modelkit");
 var sym = this.vwr.getOperativeSymmetry();
@@ -990,7 +1029,7 @@ n = -pts.length;
 this.assignAtomNoAddedSymmetry(pts[0], atomIndex, null, type, true, cmd, -1);
 n = -1;
 }} else {
-n = this.addAtomsWithSymmetry(sym, bsAtoms, type, atomIndex, isPoint, pts, opsCtr, packing);
+n = this.addAtomsWithSymmetry(sym, bsAtoms, type, atomIndex, isPoint, pts, opsCtr, packing, uc);
 }return n;
 } catch (e) {
 if (Clazz.exceptionOf(e, Exception)){
@@ -1002,9 +1041,9 @@ throw e;
 } finally {
 this.vwr.popHoldRepaint("modelkit");
 }
-}, "~S,~A,JU.BS,~A,~N,~S");
+}, "~S,~A,JU.BS,~A,~N,J.api.SymmetryInterface,~S");
 Clazz.defineMethod(c$, "addAtomsWithSymmetry", 
-function(sym, bsAtoms, type, atomIndex, isPoint, pts, opsCtr, packing){
+function(sym, bsAtoms, type, atomIndex, isPoint, pts, opsCtr, packing, uc){
 var flags = "";
 var bsM = this.vwr.getThisModelAtoms();
 var n = bsM.cardinality();
@@ -1032,7 +1071,7 @@ flags = "fromfractional;tocartesian;" + flags;
 if (isPoint) {
 var bsEquiv = (bsAtoms == null ? null : this.vwr.ms.getSymmetryEquivAtoms(bsAtoms, null, null));
 for (var i = 0; i < pts.length; i++) {
-this.assignAtoms(JU.Point3fi.newPF(pts[i], 1), atomIndex, bsEquiv, stype, true, null, false, site, sym, points, flags, null, packing);
+this.assignAtoms(JU.Point3fi.newPF(pts[i], 1), atomIndex, bsEquiv, stype, true, null, false, site, sym, points, flags, null, packing, uc);
 }
 } else {
 var sites =  new JU.BS();
@@ -1043,7 +1082,7 @@ site = a.getAtomSite();
 if (sites.get(site)) continue;
 sites.set(site);
 stype = (type == null ? a.getElementSymbolIso(true) : stype);
-this.assignAtoms(this.encodeVib(spinSym, a), -1, null, stype, false, null, false, site, sym, points, flags, opsCtr, packing);
+this.assignAtoms(this.encodeVib(spinSym, a), -1, null, stype, false, null, false, site, sym, points, flags, opsCtr, packing, uc);
 if (opsCtr == null) {
 for (var j = points.size(); --j >= nInitial; ) points.removeItemAt(j);
 
@@ -1055,7 +1094,7 @@ sym.toFractional(p, false);
 nInitial = points.size();
 }}
 }return this.vwr.getThisModelAtoms().cardinality() - n;
-}, "J.api.SymmetryInterface,JU.BS,~S,~N,~B,~A,~A,~N");
+}, "J.api.SymmetryInterface,JU.BS,~S,~N,~B,~A,~A,~N,J.api.SymmetryInterface");
 Clazz.defineMethod(c$, "encodeVib", 
 function(spinSym, a){
 var p = JU.Point3fi.newPF(a, a.i);
@@ -1133,10 +1172,10 @@ this.vwr.runScript(script);
 }, "~S");
 Clazz.defineMethod(c$, "assignAtomNoAddedSymmetry", 
 function(pt, atomIndex, bs, type, newPoint, cmd, site){
-this.assignAtoms(JU.Point3fi.newPF(pt, 0), atomIndex, bs, type, newPoint, cmd, false, site, null, null, null, null, 0);
+this.assignAtoms(JU.Point3fi.newPF(pt, 0), atomIndex, bs, type, newPoint, cmd, false, site, null, null, null, null, 0, null);
 }, "JU.P3,~N,JU.BS,~S,~B,~S,~N");
 Clazz.defineMethod(c$, "assignAtoms", 
-function(thisPt, atomIndex, bsAtoms, type, newPoint, cmd, isClick, site, sym, points, flags, opsCtr, packing){
+function(thisPt, atomIndex, bsAtoms, type, newPoint, cmd, isClick, site, sym, points, flags, opsCtr, packing, uc){
 if (sym == null) sym = this.vwr.getOperativeSymmetry();
 var haveAtomByIndex = (atomIndex >= 0);
 var isMultipleAtoms = (bsAtoms != null && bsAtoms.cardinality() > 1);
@@ -1153,7 +1192,7 @@ if (thisPt.z != 0 && sym.getDimensionality() == 2) thisPt.z = 0;
 points.addLast(thisPt);
 if (newPoint && haveAtomByIndex) {
 nIgnored++;
-}sym.getEquivPointList(nIgnored, flags + (newPoint && atomIndex < 0 ? "newpt" : ""), opsCtr, packing, points);
+}sym.getEquivPointList(nIgnored, flags + (newPoint && atomIndex < 0 ? "newpt" : ""), opsCtr, packing, points, uc);
 }var bsEquiv = (atom == null ? null : sym != null ? this.vwr.ms.getSymmetryEquivAtoms(bsAtoms, sym, null) : bsAtoms == null || bsAtoms.cardinality() == 0 ? JU.BSUtil.newAndSetBit(atomIndex) : bsAtoms);
 var bs0 = (bsEquiv == null ? null : sym == null ? JU.BSUtil.newAndSetBit(atomIndex) : JU.BSUtil.copy(bsEquiv));
 var mi = (atom == null ? this.vwr.am.cmi : atom.mi);
@@ -1277,7 +1316,7 @@ throw ex;
 } finally {
 this.setMKState(state);
 }
-}, "JU.Point3fi,~N,JU.BS,~S,~B,~S,~B,~N,J.api.SymmetryInterface,JU.Lst,~S,~A,~N");
+}, "JU.Point3fi,~N,JU.BS,~S,~B,~S,~B,~N,J.api.SymmetryInterface,JU.Lst,~S,~A,~N,J.api.SymmetryInterface");
 Clazz.defineMethod(c$, "assignAtom", 
 function(atomIndex, type, autoBond, addHsAndBond, isClick){
 if (isClick) {
@@ -2096,19 +2135,14 @@ this.vwr.toFractionalUC(sym, fxyz[k], false);
 return fxyz;
 }, "J.api.SymmetryInterface,JU.BS");
 Clazz.defineMethod(c$, "packAssignedSpaceGroup", 
-function(sym, bsAtoms, transform, packing, cmd){
-if (sym == null) sym = this.vwr.getOperativeSymmetry();
-if (sym == null) return 0;
+function(sym, bsAtoms, transform, packing, uc, cmd){
+if (sym == null && (sym = this.vwr.getOperativeSymmetry()) == null) return 0;
 var opsCtr = (transform == null ? null : sym.getSpaceGroupInfoObj("opsCtr", transform, false, false));
 var n0 = bsAtoms.cardinality();
-this.addAtoms(null, null, bsAtoms, opsCtr, packing, cmd);
-this.vwr.ms.setSpaceGroup(this.vwr.am.cmi, sym,  new JU.BS());
+this.addAtoms(null, null, bsAtoms, opsCtr, packing, uc, cmd);
+if (uc == null) this.vwr.ms.setSpaceGroup(this.vwr.am.cmi, sym,  new JU.BS());
 return this.vwr.getThisModelAtoms().cardinality() - n0;
-}, "J.api.SymmetryInterface,JU.BS,~S,~N,~S");
-Clazz.defineMethod(c$, "packUnitCell", 
-function(sym, bsAtoms, packing){
-this.packAssignedSpaceGroup(sym, bsAtoms, null, packing, "packUC");
-}, "J.api.SymmetryInterface,JU.BS,~N");
+}, "J.api.SymmetryInterface,JU.BS,~S,~N,J.api.SymmetryInterface,~S");
 Clazz.defineMethod(c$, "updateDrawAtomSymmetry", 
 function(mode, atoms){
 if (this.drawAtomSymmetry == null) return;
@@ -2232,8 +2266,6 @@ if (sym == null) return "";
 origin = this.vwr.shm.getShapePropertyIndex(34, "originPoint", 0);
 var axisPoints;
 pts = axisPoints = this.vwr.shm.getShapePropertyIndex(34, "axisPoints", 0);
-var s = "";
-var colors =  Clazz.newArray(-1, ["red", "green", "blue"]);
 var nDim = sym.getDimensionality();
 var periodicity = sym.getPeriodicity();
 shiftA = ((periodicity & 0x1) == 0);
@@ -2275,29 +2307,15 @@ if (options != 0 && options != 1296041985) {
 var o = this.vwr.getSymmetryInfo(iatom, xyz, iSym, trans, center, target, 134217751, null, intScale / 100, nth, options, opList);
 if (Clazz.instanceOf(o,"JU.P3")) target = o;
  else s = "";
-}if (thisId == null) thisId = (isSymop ? "sym_" + (options == 1296041985 ? "spin" : "") : "sg");
-if (s == null) s = this.vwr.getSymmetryInfo(iatom, xyz, iSym, trans, center, target, 135176, thisId, Clazz.doubleToInt(intScale / 100), nth, options, opList);
-if (s != null) {
-s = "draw ID \"" + (isSymop || options == 1095241729 ? "sg" : "sym_") + "*\" delete;" + s;
+}if (thisId == null) thisId = (isSymop ? "sym_" : "sg");
+if (s == null) {
+s = this.vwr.getSymmetryInfo(iatom, xyz, iSym, trans, center, target, 135176, thisId, Clazz.doubleToInt(intScale / 100), nth, options, opList);
+}if (s != null) {
+s = "draw ID \"" + (isSymop ? "sg" : "sym_") + "*\" delete;" + s;
 s = "draw ID \"" + thisId + "*\" delete;" + s;
-}if (isModelkit) s += ";draw ID sg_xes axes 0.05;";
+}if (isModelkit) s += ";draw ID sg_axes axes 0.05;";
 return s;
 }, "~S,~B,~N,~S,~N,JU.P3,JU.P3,JU.P3,~N,~N,~N,~A,~B");
-Clazz.defineMethod(c$, "cmdAssignSpaceGroup", 
-function(transform, sb, cmd, packing, doDraw){
-this.clearAtomConstraints();
-if (packing >= 0) {
-var n;
-if (doDraw) {
-n = this.cmdAssignAddAtoms("N:G", null, null, packing, cmd);
-} else {
-var bsModelAtoms = this.vwr.getThisModelAtoms();
-n = this.packAssignedSpaceGroup(null, bsModelAtoms, transform, packing, cmd);
-}sb.append("\n").append(J.i18n.GT.i(J.i18n.GT.$("{0} atoms added"), n));
-}if (doDraw) {
-var s = this.drawSymmetry("sg", false, -1, null, 2147483647, null, null, null, 0, -2, 0, null, true);
-this.appRunScript(s);
-}}, "~S,JU.SB,~S,~N,~B");
 c$.$ModelKit$DrawAtomSet$ = function(){
 /*if4*/;(function(){
 var c$ = Clazz.decorateAsClass(function(){
@@ -2721,4 +2739,4 @@ c$.GET = 0;
 c$.GET_CREATE = 1;
 c$.GET_DELETE = 2;
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
