@@ -709,4 +709,4 @@ if (name.indexOf("captureLooping") >= 0) info = (this.vwr.am.animationReplayMode
 return (info == null ? text : text.substring(0, pt) + " (" + info + ")");
 }, "~S,~S");
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
