@@ -647,4 +647,4 @@ c$.nf = java.text.NumberFormat.getInstance();
 J.quantum.NMRNoeMatrix.nf.setMinimumFractionDigits(4);
 J.quantum.NMRNoeMatrix.nf.setMaximumFractionDigits(4);
 }});
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Mon Jan 19 20:38:07 CST 2026
