@@ -53,4 +53,4 @@ var x = Clazz.doubleToInt(Math.floor(5 * this.imageFontScaling));
 this.g3d.drawStringNoSlab(frameTitle, null, x, y, 0, 0);
 }, "~S");
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:53:24 CST 2026
