@@ -36,4 +36,4 @@ if (label == null || atom == null) return null;
 return (this.ms.isJmolDataFrame(atom.mi) && label.equals("%U") ? "%W" : label);
 }, "JM.Atom,~S");
 });
-;//5.0.1-v7 Sun Jan 11 17:34:42 CST 2026
+;//5.0.1-v7 Mon Jan 19 20:38:07 CST 2026
