@@ -364,4 +364,4 @@ this.mesh.normals = null;
 this.mesh.bsPolygons = null;
 }, "~N");
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
