@@ -47,4 +47,4 @@ if (this.mar > 0) this.g3d.fillCylinderXYZ(this.colix, this.colix, 2, this.width
  else this.g3d.drawLineXYZ(xA, yA, zA, xB, yB, zB);
 }, "~N,~N,~N,~N,~N,~N");
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
