@@ -54,4 +54,4 @@ lastWasHelix = isHelix && !this.helixRockets;
 if (doRockets) this.renderRockets();
 });
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
