@@ -200,4 +200,4 @@ if (this.standardVector && !vib.isFrom000) this.g3d.fillCylinderBits(2, this.dia
 }if (this.drawCap) this.g3d.fillConeScreen3f(2, this.headWidthPixels, this.screenArrowHead, this.screenVectorEnd, false);
 }, "JM.Atom,JU.Vibration");
 });
-;//5.0.1-v7 Sun Jan 11 17:34:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
