@@ -63,4 +63,4 @@ return null;
 });
 c$.frankString = "Jmol";
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:49:55 CST 2026
