@@ -83,4 +83,4 @@ var rd =  new J.atomdata.RadiusData(data, 0, J.atomdata.RadiusData.EnumType.ABSO
 this.setShapeSizeRD(0, rd, bsAtoms);
 }, "~A,JU.BS");
 });
-;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
