@@ -40,6 +40,7 @@ this.defaultFontId0 = -1;
 this.defaultFontId = -1;
 this.thisFontID = -1;
 this.titleColor = null;
+this.imodel = -1;
 this.slabData = null;
 this.vAB = null;
 this.ptXY = null;
@@ -145,11 +146,15 @@ var fdata = value;
 var n = Clazz.doubleToInt(fdata.length / 6);
 for (var i = 0, pt = 0; i < n; i++) this.lineData.addLast( Clazz.newArray(-1, [JU.P3.new3(fdata[pt++], fdata[pt++], fdata[pt++]), JU.P3.new3(fdata[pt++], fdata[pt++], fdata[pt++])]));
 
+return;
+}if ("imodel" === propertyName) {
+this.imodel = (value).intValue();
 return;
 }if ("modelIndex" === propertyName) {
 this.indicatedModelIndex = (value).intValue();
 if (this.indicatedModelIndex < 0 || this.indicatedModelIndex >= this.ms.mc) return;
-this.vData.addLast( Clazz.newArray(-1, [Integer.$valueOf(4), (this.modelInfo =  Clazz.newIntArray(-1, [this.indicatedModelIndex, 0]))]));
+this.modelInfo =  Clazz.newIntArray(-1, [this.indicatedModelIndex, 0]);
+this.vData.addLast( Clazz.newArray(-1, [Integer.$valueOf(4), this.modelInfo]));
 if (this.thisMesh.thisID.startsWith("_!_")) this.indicatedModelOnly = true;
 return;
 }if ("planedef" === propertyName) {
@@ -415,12 +420,12 @@ this.thisMesh.diameter = this.diameter;
 this.thisMesh.width = this.width;
 if (this.plane != null) {
 if (this.intersectID != null) {
-var vData =  new JU.Lst();
-var data =  Clazz.newArray(-1, [this.intersectID, this.plane, vData, null]);
+var pts =  new JU.Lst();
+var data =  Clazz.newArray(-1, [this.intersectID, this.plane, pts, null]);
 this.vwr.shm.getShapePropertyData(24, "intersectPlane", data);
-if (vData.size() > 0) {
+if (pts.size() > 0) {
 this.indicatedModelIndex = (data[3]).intValue();
-this.lineData = vData;
+this.lineData = pts;
 }} else if (this.slabData != null) {
 this.slabData.getMeshSlicer().getIntersection(0, this.plane, null, null, null, null, null, false, true, 134217750, false);
 this.polygon =  new JU.Lst();
@@ -428,8 +433,8 @@ this.polygon.addLast(this.slabData.vs);
 this.polygon.addLast(this.slabData.pis);
 }}if (this.polygon == null && (this.lineData != null ? this.lineData.size() == 0 : (this.vData.size() == 0) == (connections == null)) || !this.isArrow && connections != null) return false;
 var modelCount = this.ms.mc;
-if (this.polygon != null || this.lineData != null || this.indicatedModelIndex < 0 && (this.isFixed || this.isArrow || this.isCurve || this.isCircle || this.isCylinder || modelCount == 1)) {
-this.thisMesh.modelIndex = (this.lineData == null ? this.vwr.am.cmi : this.indicatedModelIndex);
+if (this.imodel >= 0 || this.polygon != null || this.lineData != null || this.indicatedModelIndex < 0 && (this.isFixed || this.isArrow || this.isCurve || this.isCircle || this.isCylinder || modelCount == 1)) {
+this.thisMesh.modelIndex = (this.imodel >= 0 ? this.imodel : this.lineData == null ? this.vwr.am.cmi : this.indicatedModelIndex);
 this.thisMesh.isFixed = (this.isFixed || this.lineData == null && this.thisMesh.modelIndex < 0 && modelCount > 1);
 if (this.isFixed && modelCount > 1) this.thisMesh.modelIndex = -1;
  else if (this.lineData == null && this.thisMesh.modelIndex < 0) this.thisMesh.modelIndex = 0;
@@ -502,6 +507,7 @@ return true;
 }, "~A");
 Clazz.overrideMethod(c$, "clean", 
 function(){
+this.imodel = -1;
 for (var i = this.meshCount; --i >= 0; ) if (this.meshes[i] == null || this.meshes[i].vc == 0 && this.meshes[i].connectedAtoms == null && this.meshes[i].lineData == null) this.deleteMeshI(i);
 
 });
@@ -1280,4 +1286,4 @@ Clazz.defineEnumConstant(c$, "LINE_SEGMENT", 11, [20, "lineSegment"]);
 Clazz.defineEnumConstant(c$, "POLYGON", 12, [21, "polygon"]);
 /*eoif2*/})();
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
