@@ -97,4 +97,4 @@ return this.haveXyPoints;
 }
 });
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 21:05:04 CST 2026
