@@ -543,4 +543,4 @@ cp.xVdwClash = ((x / 2));
 }}, "JU.ContactPair,~N,~N,~N,~N");
 c$.rdVDW =  new J.atomdata.RadiusData(null, 1, J.atomdata.RadiusData.EnumType.FACTOR, J.c.VDW.AUTO);
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
