@@ -224,4 +224,4 @@ this.lcaoReverseColor = lc.lcaoReverseColor;
 Clazz.superCall(this, J.shapesurface.LcaoCartoon, "merge", [shape]);
 }, "J.shape.MeshCollection");
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Mon Jan 19 20:38:07 CST 2026
