@@ -152,4 +152,4 @@ return JU.Quat.getQuaternionFrameV(vA, vB, vC, false);
 }, "~S");
 c$.alphaOffsets =  Clazz.newByteArray(-1, [0]);
 });
-;//5.0.1-v7 Sat Jan 10 12:11:03 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:53:24 CST 2026
