@@ -2078,7 +2078,7 @@ this.tainted[12].or(bsVib);
 }, "~N");
 Clazz.defineMethod(c$, "getAtomsFromAtomNumberInFrame", 
 function(atomNumber){
-var bs = this.vwr.getFrameAtoms();
+var bs = this.vwr.getVisibleFrameAtomsNoSplitData();
 for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) if (this.at[i].getAtomNumber() != atomNumber) bs.clear(i);
 
 return bs;
@@ -2109,4 +2109,4 @@ c$.sqrt3_2 = Math.sqrt(3) / 2;
 c$.vRef = JU.V3.new3(3.14159, 2.71828, 1.41421);
 c$.userSettableValues = null;
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
