@@ -19,4 +19,4 @@ if (this.associatedAtoms == null) this.associatedAtoms = ms.getAtomIndices(ms.ge
 return this.associatedAtoms;
 }, "JM.ModelSet");
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
