@@ -1,5 +1,5 @@
 Clazz.declarePackage("JM");
-Clazz.load(null, "JM.Model", ["java.util.Hashtable", "JU.AU", "$.BS", "$.SB", "JS.T", "JU.BSUtil", "JV.FileManager"], function(){
+Clazz.load(null, "JM.Model", ["java.util.Hashtable", "JU.AU", "$.BS", "$.M3", "$.P3", "$.SB", "JS.T", "JU.BSUtil", "JV.FileManager"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.ms = null;
 this.mat4 = null;
@@ -43,7 +43,7 @@ this.jmolData = null;
 this.jmolFrameType = null;
 this.jmolFrameTypeInt = 0;
 this.dataFrames = null;
-this.dataSourceFrame = -1;
+this.dataSourceFrame = 0;
 this.uvw = null;
 this.uvw0 = null;
 this.pdbID = null;
@@ -191,5 +191,17 @@ function(ucell){
 if ((this.simpleCage = ucell) != null) {
 this.auxiliaryInfo.put("unitCellParams", ucell.getUnitCellParams());
 }}, "J.api.SymmetryInterface");
+Clazz.defineMethod(c$, "getUVWMatrix", 
+function(isUVW0){
+if (this.uvw0 == null) {
+return null;
+}var m =  new JU.M3();
+for (var i = 0; i < 3; i++) {
+var p = JU.P3.newP(isUVW0 ? this.uvw0[i] : this.uvw[i]);
+p.normalize();
+m.setColumnV(i, p);
+}
+return m;
+}, "~B");
 });
-;//5.0.1-v7 Sun Jan 11 17:34:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
