@@ -77,4 +77,4 @@ return this.getHelixData2(tokType, qType, mStep);
 c$.phosphorusOffsets =  Clazz.newByteArray(-1, [0]);
 c$.MAX_ADJACENT_PHOSPHORUS_DISTANCE = 8.0;
 });
-;//5.0.1-v7 Sat Jan 10 12:11:03 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:53:24 CST 2026
