@@ -1,6 +1,13 @@
 Clazz.declarePackage("JS");
-Clazz.load(["java.util.Hashtable", "JU.M3", "$.V3"], "JS.PointGroup", ["JU.Lst", "$.P3", "$.PT", "$.Quat", "$.SB", "J.bspt.Bspt", "JU.BSUtil", "$.Escape", "$.Logger", "$.Point3fi"], function(){
+Clazz.load(["java.util.Hashtable", "JU.M3", "$.V3"], "JS.PointGroup", ["JU.Lst", "$.P3", "$.PT", "$.Quat", "$.SB", "J.bspt.Bspt", "JS.SymmetryOperation", "JU.BSUtil", "$.Escape", "$.Logger", "$.Point3fi"], function(){
 var c$ = Clazz.decorateAsClass(function(){
+this.operations = null;
+if (!Clazz.isClassDefined("JS.PointGroup.Operation")) {
+JS.PointGroup.$PointGroup$Operation$ ();
+}
+if (!Clazz.isClassDefined("JS.PointGroup.Operator")) {
+JS.PointGroup.$PointGroup$Operator$ ();
+}
 this.maxAtoms = 250;
 this.maxElement = 0;
 this.eCounts = null;
@@ -39,6 +46,12 @@ this.localEnvOnly = false;
 this.$isLinear = false;
 this.sppa = 0;
 this.isSpinGroup = false;
+this.highestOrder = 0;
+this.modelIndex = 0;
+this.drawID = null;
+this.type = null;
+this.index = 0;
+this.scaleFactor = 0;
 Clazz.instantialize(this, arguments);}, JS, "PointGroup", null);
 Clazz.prepareFields (c$, function(){
 this.nAxes =  Clazz.newIntArray (JS.PointGroup.maxAxis, 0);
@@ -49,6 +62,35 @@ Clazz.makeConstructor(c$,
 function(isHM){
 this.convention = (isHM ? 1 : 0);
 }, "~B");
+Clazz.defineMethod(c$, "newInversionCenter", 
+function(index){
+return Clazz.innerTypeInstance(JS.PointGroup.Operator, this, null, index, null, -1);
+}, "~N");
+Clazz.defineMethod(c$, "newPlane", 
+function(index, v){
+return Clazz.innerTypeInstance(JS.PointGroup.Operator, this, null, index, v, -1);
+}, "~N,JU.V3");
+Clazz.defineMethod(c$, "newAxis", 
+function(index, v, arrayIndex){
+return Clazz.innerTypeInstance(JS.PointGroup.Operator, this, null, index, v, arrayIndex);
+}, "~N,JU.V3,~N");
+c$.getUniqueFractions = Clazz.defineMethod(c$, "getUniqueFractions", 
+function(order){
+var bs = JS.PointGroup.bsUnique.get(Integer.$valueOf(order));
+if (bs != null) return bs;
+bs = JU.BSUtil.newBitSet2(1, order);
+var n = Clazz.doubleToInt(order / 2);
+for (var i = 1; i <= n; i++) {
+var f = Clazz.doubleToInt(order / i);
+if (f * i != order || !bs.get(f)) continue;
+for (var j = f; j <= n; j += f) {
+bs.clear(j);
+bs.clear(order - j);
+}
+}
+JS.PointGroup.bsUnique.put(Integer.$valueOf(order), bs);
+return bs;
+}, "~N");
 c$.getPointGroup = Clazz.defineMethod(c$, "getPointGroup", 
 function(pgLast, center, atomset, bsAtoms, haveVibration, distanceTolerance, linearTolerance, maxAtoms, localEnvOnly, isHM, sppa){
 var pg =  new JS.PointGroup(isHM);
@@ -78,7 +120,6 @@ JU.Logger.error("Too many atoms for point group calculation");
 this.name = "point group not determined -- ac > " + this.maxAtoms + " -- select fewer atoms and try again.";
 return true;
 }this.getElementCounts();
-if (this.haveVibration) {
 var atomVibs =  new Array(this.points.length);
 for (var i = 0; i < this.points.length; i++) {
 atomVibs[i] = JU.P3.newP(this.points[i]);
@@ -87,11 +128,14 @@ if (v != null) {
 if (v.isFrom000) {
 this.isSpinGroup = true;
 atomVibs = null;
+this.haveVibration = true;
+break;
+} else if (!this.haveVibration) {
 break;
 }atomVibs[i].add(v);
 }}
-if (atomVibs != null) this.points = atomVibs;
-}if (this.isEqual(pgLast)) return false;
+if (this.haveVibration && atomVibs != null) this.points = atomVibs;
+if (this.isEqual(pgLast)) return false;
 try {
 this.findInversionCenter();
 this.$isLinear = this.isLinear(this.points);
@@ -104,7 +148,7 @@ this.name = "C\u221ev";
 this.addAxis(22, this.vTemp);
 this.principalAxis = this.axes[22][0];
 if (this.haveInversionCenter) {
-this.axes[0] =  Clazz.newArray(-1, [this.principalPlane = JS.PointGroup.Operation.newPlane(++this.nOps, this.vTemp)]);
+this.axes[0] =  Clazz.newArray(-1, [this.principalPlane = this.newPlane(++this.nOps, this.vTemp)]);
 this.nAxes[0] = 1;
 }return true;
 }this.axes[0] =  new Array(JS.PointGroup.axesMaxN[0]);
@@ -286,7 +330,7 @@ Clazz.defineMethod(c$, "findInversionCenter",
 function(){
 this.haveInversionCenter = this.checkOperation(null, this.center, -1);
 if (this.haveInversionCenter) {
-this.axes[1] =  Clazz.newArray(-1, [JS.PointGroup.Operation.newInversionCenter(++this.nOps)]);
+this.axes[1] =  Clazz.newArray(-1, [this.newInversionCenter(++this.nOps)]);
 this.nAxes[1] = 1;
 }});
 Clazz.defineMethod(c$, "setPrincipalAxis", 
@@ -528,7 +572,7 @@ Clazz.defineMethod(c$, "addAxis",
 function(arrayIndex, v){
 if (this.haveAxis(arrayIndex, v)) return;
 if (this.axes[arrayIndex] == null) this.axes[arrayIndex] =  new Array(JS.PointGroup.axesMaxN[arrayIndex]);
-this.axes[arrayIndex][this.nAxes[arrayIndex]++] = JS.PointGroup.Operation.newAxis(++this.nOps, v, arrayIndex);
+this.axes[arrayIndex][this.nAxes[arrayIndex]++] = this.newAxis(++this.nOps, v, arrayIndex);
 }, "~N,JU.V3");
 Clazz.defineMethod(c$, "findPlanes", 
 function(){
@@ -585,17 +629,29 @@ this.checkForAxis(22, this.vTemp);
 }}, "~N");
 Clazz.defineMethod(c$, "addPlane", 
 function(v3){
-if (!this.haveAxis(0, v3) && this.checkOperation(JU.Quat.newVA(v3, 180), this.center, -1)) this.axes[0][this.nAxes[0]++] = JS.PointGroup.Operation.newPlane(++this.nOps, v3);
+if (!this.haveAxis(0, v3) && this.checkOperation(JU.Quat.newVA(v3, 180), this.center, -1)) this.axes[0][this.nAxes[0]++] = this.newPlane(++this.nOps, v3);
 return this.nAxes[0];
 }, "JU.V3");
 Clazz.defineMethod(c$, "getName", 
 function(){
 return this.getNameByConvention(this.name);
 });
+Clazz.defineMethod(c$, "updateDraw", 
+function(){
+return null;
+});
 Clazz.defineMethod(c$, "getInfo", 
-function(modelIndex, drawID, asMap, type, index, scaleFactor){
-if (drawID == null && !asMap && this.textInfo != null) return this.textInfo;
-if (drawID == null && this.drawInfo != null && this.drawIndex == index && this.scale == this.scale && this.drawType.equals(type == null ? "" : type)) return this.drawInfo;
+function(modelIndex, a1, a2, drawID, asMap, type, index, scaleFactor){
+if (drawID == null && type == null && !asMap && this.textInfo != null) return this.textInfo;
+if (drawID != null) {
+this.modelIndex = modelIndex;
+this.drawID = drawID;
+this.type = type;
+this.index = index;
+this.scaleFactor = scaleFactor;
+}this.operations =  new JU.Lst();
+var justThisUVW = (type != null && type.indexOf("u") >= 0);
+if (a1 == null && a2 == null && drawID == null && this.drawInfo != null && this.drawIndex == index && this.scale == this.scale && this.drawType.equals(type == null ? "" : type)) return this.drawInfo;
 if (asMap && this.info != null) return this.info;
 var asDraw = (drawID != null);
 this.info = null;
@@ -610,19 +666,32 @@ for (var i = 1; i < JS.PointGroup.maxAxis; i++) for (var j = this.nAxes[i]; --j
 
 var sb =  new JU.SB().append("# ").appendI(this.nAtoms).append(" atoms\n");
 var name = this.getNameByConvention(this.name);
-if (asDraw) {
-drawID = "draw " + drawID;
+var haveThisType = false;
+var operationInv = (this.haveInversionCenter ? Clazz.innerTypeInstance(JS.PointGroup.Operation, this, null, null) : null);
+if (operationInv != null) {
+this.operations.addLast(operationInv);
+}if (asDraw) {
 var haveType = (type != null && type.length > 0);
 this.drawType = type = (haveType ? type : "");
 this.drawIndex = index;
 var anyProperAxis = (type.equalsIgnoreCase(this.getNameByConvention("Cn")));
 var anyImproperAxis = (type.equalsIgnoreCase(this.getNameByConvention("Sn")));
-sb.append("set perspectivedepth off;" + drawID + "* delete;\n");
+var head = "set perspectivedepth off;draw " + drawID + " delete;\n";
 var m = "_" + modelIndex + "_";
-if (!haveType) sb.append(drawID + "pg0").append(m).append("* delete;draw pgva").append(m).append("* delete;draw pgvp").append(m).append("* delete;");
-if (!haveType || type.equalsIgnoreCase("Ci")) sb.append(drawID + "pg0").append(m).append(this.haveInversionCenter ? "inv " : " ").append(JU.Escape.eP(this.center)).append(this.haveInversionCenter ? "\"i\";\n" : ";\n");
-var offset = 0.1;
-for (var i = 2; i < JS.PointGroup.maxAxis; i++) {
+if (justThisUVW || !haveType) sb.append(this.getDrawID("pg0" + m + "* delete;") + this.getDrawID("pgva" + m + "* delete;") + this.getDrawID("pgvp" + m + "* delete;"));
+if (!haveType || type.equalsIgnoreCase("Ci") || type.equalsIgnoreCase("-u,-v,-w")) {
+var pt = sb.length();
+sb.append(this.getDrawID("pg0" + m + (this.haveInversionCenter ? "inv" : "")));
+if (operationInv != null) {
+operationInv.drawID = sb.substring(pt);
+haveThisType = justThisUVW;
+}sb.append(" ").append(JU.Escape.eP(this.center)).append(this.haveInversionCenter ? "\"i\";\n" : ";\n");
+if (operationInv != null) {
+operationInv.drawStr = sb.substring(pt);
+System.out.println(operationInv);
+}}var offset = 0.1;
+var axisWidth = (this.isSpinGroup ? 1.9 : 0.05);
+for (var i = 2; i < JS.PointGroup.maxAxis && !haveThisType; i++) {
 if (i == 20) offset = 0.1;
 if (this.nAxes[i] == 0) continue;
 var sglabel = (this.$isLinear ? "C\u221e" : this.getOpName(this.axes[i][0], false));
@@ -630,45 +699,54 @@ var label = (this.$isLinear ? "\u221e" : this.getOpName(this.axes[i][0], true));
 offset += 0.25;
 var scale = scaleFactor * 1.05 * this.radius + offset * 80 / this.sppa;
 var isProper = (i >= 20);
-if (!haveType || type.equalsIgnoreCase(label) || anyProperAxis && isProper || anyImproperAxis && !isProper) {
+this.highestOrder = this.getHighestOrder();
+if (justThisUVW || !haveType || type.equalsIgnoreCase(label) || anyProperAxis && isProper || anyImproperAxis && !isProper) {
 for (var j = 0; j < this.nAxes[i]; j++) {
 if (index > 0 && j + 1 != index) continue;
 op = this.axes[i][j];
-v.add2(op.normalOrAxis, this.center);
-sb.append(drawID + "pgva").append(m).append(sglabel).append("_").appendI(j + 1).append(" width 0.05 scale ").appendD(op.type == 2 ? -scale : scale).append(" ").append(JU.Escape.eP(v));
-v.scaleAdd2(-2, op.normalOrAxis, v);
-var isPA = (!this.$isLinear && this.principalAxis != null && op.index == this.principalAxis.index);
-sb.append(JU.Escape.eP(v)).append("\"").append(label).append(isPA ? "" : "").append("\" color ").append(isPA ? "red" : op.type == 2 ? "blue" : "orange").append(";\n");
+if (justThisUVW && !op.isUVW(type)) continue;
+haveThisType = justThisUVW;
+this.operations.addLast(op.operation = Clazz.innerTypeInstance(JS.PointGroup.Operation, this, null, op));
+var pt = sb.length();
+var s = this.getDrawID("pgva" + m + sglabel.$replace("\u221e", "infinity") + (j + 1) + "\1");
+op.operation.drawID = sb.substring(pt).$replace('\1', ' ');
+this.drawAxis(sb, op, s, label, axisWidth, scale, isProper, 'a', v);
+this.drawAxis(sb, op, s, label, axisWidth, scale, isProper, 'b', v);
+op.operation.drawStr = sb.substring(pt);
+if (JU.Logger.debugging) JU.Logger.debug(op.operation.toString());
 }
 }}
-if (!haveType || type.equalsIgnoreCase(this.getNameByConvention("Cs"))) {
-for (var j = 0; j < this.nAxes[0]; j++) {
+if (justThisUVW || !haveType || type.equalsIgnoreCase(this.getNameByConvention("Cs"))) {
+for (var j = 0; j < this.nAxes[0] && !haveThisType; j++) {
 if (index > 0 && j + 1 != index) continue;
 op = this.axes[0][j];
-sb.append(drawID + "pgvp").append(m).appendI(j + 1).append("disk scale ").appendD(scaleFactor * this.radius * 2).append(" CIRCLE PLANE ").append(JU.Escape.eP(this.center));
-v.add2(op.normalOrAxis, this.center);
-sb.append(JU.Escape.eP(v)).append(" color translucent yellow;\n");
-v.add2(op.normalOrAxis, this.center);
-sb.append(drawID + "pgvp").append(m).appendI(j + 1).append("ring width 0.05 scale ").appendD(scaleFactor * this.radius * 2).append(" arc ").append(JU.Escape.eP(v));
-v.scaleAdd2(-2, op.normalOrAxis, v);
-sb.append(JU.Escape.eP(v));
-v.add3(0.011, 0.012, 0.013);
-sb.append(JU.Escape.eP(v)).append("{0 360 0.5} color ").append(this.principalPlane != null && op.index == this.principalPlane.index ? "red" : "blue").append(";\n");
+if (justThisUVW && !op.isUVW(type)) continue;
+haveThisType = justThisUVW;
+this.operations.addLast(op.operation = Clazz.innerTypeInstance(JS.PointGroup.Operation, this, null, op));
+var s = op.operation.drawID = this.getDrawID("pgvp" + m + (j + 1) + "\1");
+var pt = sb.length();
+this.drawPlane(sb, op, s, scaleFactor, v);
+op.operation.drawStr = sb.substring(pt);
+if (JU.Logger.debugging) JU.Logger.debug(op.operation.toString());
 }
-}sb.append("# name=").append(name);
+if (justThisUVW && a1 != null && a2 != null) {
+var cmd = this.getDrawID("pg0" + m + "_line");
+sb.append(cmd).append(" width " + axisWidth / 2 + " " + a1 + a2 + " color yellow;");
+}}sb.append("# name=").append(name);
 sb.append(", n" + this.getNameByConvention("Ci") + "=").appendI(this.haveInversionCenter ? 1 : 0);
 sb.append(", n" + this.getNameByConvention("Cs") + "=").appendI(this.nAxes[0]);
 sb.append(", n" + this.getNameByConvention("Cn") + "=").appendI(nType[1][0]);
 sb.append(", n" + this.getNameByConvention("Sn") + "=").appendI(nType[2][0]);
 sb.append(": ");
-for (var i = JS.PointGroup.maxAxis; --i >= 2; ) if (this.nAxes[i] > 0) {
+for (var i = JS.PointGroup.maxAxis; --i >= 2; ) {
+if (this.nAxes[i] > 0) {
 var axisName = this.getNameByConvention((i < 20 ? "S" : "C") + (i % 20));
 sb.append(" n").append(axisName);
 sb.append("=").appendI(this.nAxes[i]);
-}
+}}
 sb.append(";\n");
 sb.append("print '" + name + "';\n");
-this.drawInfo = sb.toString();
+this.drawInfo = head + sb.toString();
 if (JU.Logger.debugging) JU.Logger.info(this.drawInfo);
 return this.drawInfo;
 }var n = 0;
@@ -698,20 +776,24 @@ sb.append("\n\n").append(name).append("\t").append(ctype).append("\t").append(JU
 }for (var i = JS.PointGroup.maxAxis; --i >= 0; ) {
 if (i == 1 || this.nAxes[i] == 0) continue;
 n = JS.PointGroup.nUnique[i];
-var sglabel = this.getOpName(this.axes[i][0], false);
-var label = this.getOpName(this.axes[i][0], true);
+var a = this.axes[i];
+var sglabel = this.getOpName(a[0], false);
+var label = this.getOpName(a[0], true);
+var ni = this.nAxes[i];
 if (asMap) {
 this.info.put("n" + sglabel, Integer.$valueOf(this.nAxes[i]));
 } else {
-sb.append("\n\n").append(name).append("\tn").append(label).append("\t").appendI(this.nAxes[i]).append("\t").appendI(n);
-}n *= this.nAxes[i];
+sb.append("\n\n").append(name).append("\tn").append(label).append("\t").appendI(ni).append("\t").appendI(n);
+}n *= ni;
 nTotal += n;
-nElements += this.nAxes[i];
-nType[this.axes[i][0].type][1] += n;
+nElements += ni;
+nType[a[0].type][1] += n;
 var vinfo = (asMap ?  new JU.Lst() : null);
 var minfo = (asMap ?  new JU.Lst() : null);
-for (var j = 0; j < this.nAxes[i]; j++) {
-var aop = this.axes[i][j];
+for (var j = 0; j < ni; j++) {
+var aop = a[j];
+if (type != null && !aop.isUVW(type)) continue;
+if (!asDraw && aop.operation == null) this.operations.addLast(aop.operation = Clazz.innerTypeInstance(JS.PointGroup.Operation, this, null, aop));
 if (asMap) {
 var e =  new java.util.Hashtable();
 aop.setInfo(vinfo, minfo, e);
@@ -750,7 +832,68 @@ this.info.put("detail", sb.toString().$replace('\n', ';'));
 if (this.principalAxis != null && this.principalAxis.index > 0) this.info.put("principalAxis", this.principalAxis.normalOrAxis);
 if (this.principalPlane != null && this.principalPlane.index > 0) this.info.put("principalPlane", this.principalPlane.normalOrAxis);
 return this.info;
-}, "~N,~S,~B,~S,~N,~N");
+}, "~N,JU.T3,JU.T3,~S,~B,~S,~N,~N");
+Clazz.defineMethod(c$, "getDrawID", 
+function(id){
+var pt = id.indexOf(' ');
+if (pt < 0) pt = id.length;
+id = id.substring(0, pt) + "\"" + id.substring(pt);
+return "draw" + (id.indexOf("*") >= 0 ? "" : " model " + this.modelIndex) + " ID \"" + id;
+}, "~S");
+Clazz.defineMethod(c$, "drawPlane", 
+function(sb, op, s, scaleFactor, v){
+sb.append(s.$replace("\1", "disk"));
+sb.append(" scale ").appendD(scaleFactor * this.radius * 2).append(" CIRCLE PLANE ").append(JU.Escape.eP(this.center));
+v.add2(op.normalOrAxis, this.center);
+sb.append(JU.Escape.eP(v)).append(" color translucent yellow;\n");
+v.add2(op.normalOrAxis, this.center);
+sb.append(s.$replace("\1", "ring"));
+sb.append(" width 0.05 scale ").appendD(scaleFactor * this.radius * 2).append(" arc ").append(JU.Escape.eP(v));
+v.scaleAdd2(-2, op.normalOrAxis, v);
+sb.append(JU.Escape.eP(v));
+v.add3(0.011, 0.012, 0.013);
+sb.append(JU.Escape.eP(v)).append("{0 360 0.5} color ").append(this.principalPlane != null && op.index == this.principalPlane.index ? "red" : "blue").append(";\n");
+}, "JU.SB,JS.PointGroup.Operator,~S,~N,JU.V3");
+Clazz.defineMethod(c$, "drawAxis", 
+function(sb, op, s, label, axisWidth, scale, isProper, c, v){
+var isPA = (!this.$isLinear && this.principalAxis != null && op.index == this.principalAxis.index);
+var pt = sb.length();
+sb.append(" color ").append(isPA ? "red" : op.type == 2 ? "blue" : "orange").append(";\n");
+var tail = sb.substring(pt);
+sb.setLength(pt);
+sb.append(s.$replace('\1', c));
+v.scaleAdd2((c == 'a' ? 1 : -1) * scale, op.normalOrAxis, this.center);
+sb.append(" width " + axisWidth).append(" ").append(JU.Escape.eP(this.center)).append(JU.Escape.eP(v));
+if (isProper && op.order != 2 && c == 'a' || op.order == 2 || !isProper && c == 'b') {
+label = JU.PT.esc(">" + this.getAxisLabelOffset(op, this.highestOrder) + label);
+sb.append(label);
+}sb.append(tail);
+}, "JU.SB,JS.PointGroup.Operator,~S,~S,~N,~N,~B,~S,JU.V3");
+Clazz.defineMethod(c$, "getAxisLabelOffset", 
+function(op, highestOrder){
+switch (op.type) {
+case 2:
+case 1:
+switch (op.order) {
+case 3:
+return (highestOrder % 6 == 0 ? "   " : "");
+case 4:
+return (highestOrder % 12 == 0 ? "       " : "   ");
+case 6:
+return (highestOrder % 12 == 0 ? "           " : "");
+case 8:
+return "       ";
+case 12:
+return "               ";
+default:
+return "";
+}
+default:
+case 0:
+case 3:
+return "";
+}
+}, "JS.PointGroup.Operator,~N");
 Clazz.defineMethod(c$, "getTextInfo", 
 function(sb, nType, nTotal){
 sb.append("\n");
@@ -826,7 +969,7 @@ return JS.PointGroup.getHMfromSFName(name);
 Clazz.defineMethod(c$, "getOpName", 
 function(op, conventional){
 return (conventional ? this.getNameByConvention(op.schName) : op.schName);
-}, "JS.PointGroup.Operation,~B");
+}, "JS.PointGroup.Operator,~B");
 c$.getHMfromSFName = Clazz.defineMethod(c$, "getHMfromSFName", 
 function(name){
 if (JS.PointGroup.htSFToHM == null) {
@@ -848,7 +991,7 @@ for (var n = 1; n < 13; n++) {
 var val = list[n];
 if (val.length > 0) {
 JS.PointGroup.addNames(type + n + ext, val);
-System.out.println(type + n + ext + "\t" + val);
+if (JU.Logger.debugging) JU.Logger.debug(type + n + ext + "\t" + val);
 }}
 if (list.length == 14) {
 JS.PointGroup.addNames(type + "\u221e" + ext, list[13]);
@@ -861,8 +1004,56 @@ function(sch, hm){
 JS.PointGroup.htSFToHM.put(sch, hm);
 JS.PointGroup.htSFToHM.put(hm, sch);
 }, "~S,~S");
-/*if3*/;(function(){
+c$.$PointGroup$Operation$ = function(){
+/*if4*/;(function(){
 var c$ = Clazz.decorateAsClass(function(){
+Clazz.prepareCallback(this, arguments);
+this.operator = null;
+this.drawID = null;
+this.drawStr = null;
+this.isTrivial = false;
+this.typeName = null;
+this.type = 0;
+Clazz.instantialize(this, arguments);}, JS.PointGroup, "Operation", null);
+Clazz.makeConstructor(c$, 
+function(o){
+this.operator = o;
+this.type = (o == null ? 3 : o.type);
+this.typeName = (o == null ? "Ci" : o.schName);
+this.isTrivial = this.checkTrivial();
+}, "JS.PointGroup.Operator");
+Clazz.defineMethod(c$, "checkTrivial", 
+function(){
+var tol = this.b$["JS.PointGroup"].distanceTolerance;
+for (var i = this.b$["JS.PointGroup"].points.length; --i >= 0; ) {
+var d;
+switch (this.type) {
+case 0:
+case 2:
+case 1:
+d = this.operator.distance(this.b$["JS.PointGroup"].points[i]);
+break;
+default:
+case 3:
+d = this.b$["JS.PointGroup"].points[i].length();
+break;
+}
+if (d > tol) {
+return false;
+}}
+System.out.println(this + " is trivial");
+return true;
+});
+Clazz.overrideMethod(c$, "toString", 
+function(){
+return "[op " + this.typeName + " " + this.drawID + " " + this.isTrivial + "]";
+});
+/*eoif4*/})();
+};
+c$.$PointGroup$Operator$ = function(){
+/*if4*/;(function(){
+var c$ = Clazz.decorateAsClass(function(){
+Clazz.prepareCallback(this, arguments);
 this.type = 0;
 this.index = 0;
 this.normalOrAxis = null;
@@ -870,7 +1061,12 @@ this.mat = null;
 this.order = 0;
 this.axisArrayIndex = 0;
 this.schName = null;
-Clazz.instantialize(this, arguments);}, JS.PointGroup, "Operation", null);
+this.uvws = null;
+this.uniqueMats = null;
+this.mats = null;
+this.operation = null;
+this.uniqueUVWs = null;
+Clazz.instantialize(this, arguments);}, JS.PointGroup, "Operator", null);
 Clazz.makeConstructor(c$, 
 function(index, v, arrayIndex){
 this.index = index;
@@ -892,19 +1088,7 @@ this.type = (arrayIndex < 20 ? 2 : 1);
 this.axisArrayIndex = arrayIndex;
 this.order = arrayIndex % 20;
 this.schName = (this.type == 2 ? "S" : "C") + this.order;
-}}if (JU.Logger.debugging) JU.Logger.debug("new operation -- " + this.schName + (this.normalOrAxis == null ? "" : " " + this.normalOrAxis));
-}, "~N,JU.V3,~N");
-c$.newInversionCenter = Clazz.defineMethod(c$, "newInversionCenter", 
-function(index){
-return  new JS.PointGroup.Operation(index, null, -1);
-}, "~N");
-c$.newPlane = Clazz.defineMethod(c$, "newPlane", 
-function(index, v){
-return  new JS.PointGroup.Operation(index, v, -1);
-}, "~N,JU.V3");
-c$.newAxis = Clazz.defineMethod(c$, "newAxis", 
-function(index, v, arrayIndex){
-return  new JS.PointGroup.Operation(index, v, arrayIndex);
+}}if (JU.Logger.debugging) JU.Logger.debug("new operation -- " + index + " " + this.schName + (this.normalOrAxis == null ? "" : " " + this.normalOrAxis));
 }, "~N,JU.V3,~N");
 Clazz.defineMethod(c$, "getM3", 
 function(){
@@ -914,6 +1098,12 @@ if (this.type == 0 || this.type == 2) m.mul(JS.PointGroup.mInv);
 this.cleanMatrix(m);
 return this.mat = m;
 });
+Clazz.defineMethod(c$, "distance", 
+function(pt){
+var p = JU.P3.newP(pt);
+this.getM3().rotate(p);
+return p.distance(pt);
+}, "JU.T3");
 Clazz.defineMethod(c$, "cleanMatrix", 
 function(m){
 for (var i = 0; i < 3; i++) for (var j = 0; j < 3; j++) m.setElement(i, j, this.approx0(m.getElement(i, j)));
@@ -924,35 +1114,22 @@ Clazz.defineMethod(c$, "approx0",
 function(v){
 return (v > 1e-15 || v < -1.0E-15 ? v : 0);
 }, "~N");
-Clazz.defineMethod(c$, "getUniqueMatrices", 
-function(){
+Clazz.defineMethod(c$, "getMatrices", 
+function(uniqueOnly){
+if (uniqueOnly && this.uniqueMats != null) return this.uniqueMats;
+if (!uniqueOnly && this.mats != null) return this.mats;
 var matrices =  new JU.Lst();
 var m =  new JU.M3();
 m.m00 = m.m11 = m.m22 = 1;
-var bs = JS.PointGroup.Operation.getUniqueFractions(this.order);
+var bs = (uniqueOnly ? JS.PointGroup.getUniqueFractions(this.order) : null);
 for (var i = 1; i < this.order; i++) {
 m.mul(this.getM3());
-if (bs.get(i)) matrices.addLast(JU.M3.newM3(m));
+if (!uniqueOnly || bs.get(i)) matrices.addLast(JU.M3.newM3(m));
 }
+if (uniqueOnly) this.uniqueMats = matrices;
+ else this.mats = matrices;
 return matrices;
-});
-c$.getUniqueFractions = Clazz.defineMethod(c$, "getUniqueFractions", 
-function(order){
-var bs = JS.PointGroup.Operation.bsUnique.get(Integer.$valueOf(order));
-if (bs != null) return bs;
-bs = JU.BSUtil.newBitSet2(1, order);
-var n = Clazz.doubleToInt(order / 2);
-for (var i = 1; i <= n; i++) {
-var f = Clazz.doubleToInt(order / i);
-if (f * i != order || !bs.get(f)) continue;
-for (var j = f; j <= n; j += f) {
-bs.clear(j);
-bs.clear(order - j);
-}
-}
-JS.PointGroup.Operation.bsUnique.put(Integer.$valueOf(order), bs);
-return bs;
-}, "~N");
+}, "~B");
 Clazz.overrideMethod(c$, "toString", 
 function(){
 return this.schName + " " + this.normalOrAxis;
@@ -962,15 +1139,41 @@ function(vinfo, minfo, e){
 if (vinfo != null) {
 vinfo.addLast(this.normalOrAxis);
 minfo.addLast(this.getM3());
-}e.put("typeSch", this.schName);
+}e.put("order", Integer.$valueOf(this.order));
+e.put("typeSch", this.schName);
 e.put("typeHM", JS.PointGroup.getHMfromSFName(this.schName));
 if (this.normalOrAxis != null) e.put("direction", this.normalOrAxis);
-var mats = this.getUniqueMatrices();
-e.put("matrices", mats);
-if (mats.size() != this.order - 1) e.put("matrixIndices", JS.PointGroup.Operation.bsUnique.get(Integer.$valueOf(this.order)));
+var mats = this.getMatrices(true);
+e.put("uniqueOperations", mats);
+e.put("uniqueOperationUVWs", this.getUVWs(mats, true));
+if (mats.size() != this.order - 1) e.put("matrixIndices", JS.PointGroup.bsUnique.get(Integer.$valueOf(this.order)));
+mats = this.getMatrices(false);
+e.put("operations", mats);
+e.put("operationUVWs", this.getUVWs(mats, false));
 }, "JU.Lst,JU.Lst,java.util.Map");
+Clazz.defineMethod(c$, "getUVWs", 
+function(mats, isUnique){
+var uvws = (isUnique ? this.uniqueUVWs : this.uvws);
+if (uvws != null) return uvws;
+var list =  new JU.Lst();
+for (var i = 0; i < mats.size(); i++) {
+list.addLast(JS.SymmetryOperation.staticConvertOperation(null, mats.get(i), "uvw"));
+}
+if (isUnique) this.uniqueUVWs = list;
+ else uvws = list;
+return list;
+}, "JU.Lst,~B");
+Clazz.defineMethod(c$, "isUVW", 
+function(uvw){
+var uvws = this.getUVWs(this.getMatrices(true), true);
+for (var i = 0, n = uvws.size(); i < n; i++) {
+if (uvws.get(i).equals(uvw)) return true;
+}
+return false;
+}, "~S");
+/*eoif4*/})();
+};
 c$.bsUnique =  new java.util.Hashtable();
-/*eoif3*/})();
 c$.typeNames =  Clazz.newArray(-1, ["plane", "proper axis", "improper axis", "center of inversion"]);
 c$.mInv = JU.M3.newA9( Clazz.newFloatArray(-1, [-1, 0, 0, 0, -1, 0, 0, 0, -1]));
 c$.axesMaxN =  Clazz.newIntArray(-1, [49, 0, 0, 1, 3, 1, 10, 1, 1, 0, 6, 0, 1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 49, 10, 6, 6, 10, 1, 1]);
@@ -979,4 +1182,4 @@ c$.maxAxis = JS.PointGroup.axesMaxN.length;
 c$.SF2HM = ("Cn,1,2,3,4,5,6,7,8,9,10,11,12|Cnv,m,2m,3m,4mm,5m,6mm,7m,8mm,9m,10mm,11m,12mm,\u221em|Sn,,-1,-6,-4,(-10),-3,(-14),-8,(-18),-5,(-22),(-12)|Cnh,m,2/m,-6,4/m,-10,6/m,-14,8/m,-18,10/m,-22,12/m|Dn,,222,32,422,52,622,72,822,92,(10)22,(11)2,(12)22|Dnd,,-42m,-3m,-82m,-5m,(-12)2m,-7m,(-16)2m,-9m,(-20)2m,(-11)m,(-24)2m|Dnh,,mmm,-6m2,4/mmm,(-10)m2,6/mmm,(-14)m2,8/mmm,(-18)m2,10/mmm,(-22)m2,12/mmm,\u221e/mm|Ci,-1|Cs,m|T,23|Th,m-3|Td,-43m|O,432|Oh,m-3m").$plit("\\|");
 c$.htSFToHM = null;
 });
-;//5.0.1-v7 Sat Jan 10 12:43:18 CST 2026
+;//5.0.1-v7 Mon Jan 19 21:13:04 CST 2026
