@@ -241,7 +241,7 @@ v = this.getPointOrPlane(i, 55);
 }i = this.iToken;
 break;
 case 1073742340:
-v = this.vwr.getFrameAtoms();
+v = this.vwr.getVisibleFrameAtomsNoSplitData();
 i = this.iToken;
 break;
 case 1073742325:
@@ -670,7 +670,7 @@ rpn.addXBs(this.getAtomBits(instruction.tok, value));
 break;
 case 1073742340:
 case 2097182:
-rpn.addXBs(this.vwr.am.cmi < 0 ? this.vwr.getFrameAtoms() : this.vwr.getModelUndeletedAtomsBitSet(this.vwr.am.cmi));
+rpn.addXBs(this.vwr.getVisibleFrameAtomsNoSplitData());
 break;
 case 1612709900:
 case 2097154:
@@ -1975,4 +1975,4 @@ var f = (this.privateFuncs == null ? null : this.privateFuncs.get(sf));
 return (f == null ? this.vwr.getFunction(sf) : f);
 }, "~S");
 });
-;//5.0.1-v7 Sat Jan 10 13:07:22 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
