@@ -596,4 +596,4 @@ if (this.isAromatic) s = s.toLowerCase();
 return "[" + s + '.' + this.index + (this.matchingIndex >= 0 ? "(" + this.matchingNode + ")" : "") + "]";
 });
 });
-;//5.0.1-v7 Sat Jan 10 12:11:03 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:53:24 CST 2026
