@@ -930,4 +930,4 @@ JS.SmilesParser.extractFlags(pattern, ret);
 return ret[0];
 }, "~S");
 });
-;//5.0.1-v7 Sat Jan 10 12:11:03 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:53:24 CST 2026
