@@ -31,4 +31,4 @@ var j = e.getAtomIndex2();
 return (i < j ? i + "_" + j : j + "_" + i);
 }, "JU.Edge");
 });
-;//5.0.1-v7 Thu Dec 18 09:19:10 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
