@@ -34,4 +34,4 @@ function(vwr, sym, name, type){
 return this.createSpecialGroup(null, sym, JS.Symmetry.getSpecialSettingInfo(vwr, name, type), type);
 }, "JV.Viewer,JS.Symmetry,~S,~N");
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 17:42:06 CST 2026
