@@ -36,7 +36,7 @@ return this.pointGroup.getName();
 });
 Clazz.overrideMethod(c$, "getPointGroupInfo", 
 function(modelIndex, drawID, asInfo, type, index, scale){
-return this.pointGroup.getInfo(modelIndex, drawID, asInfo, type, index, scale);
+return this.pointGroup.getInfo(modelIndex, null, null, drawID, asInfo, type, index, scale);
 }, "~N,~S,~B,~S,~N,~N");
 Clazz.overrideMethod(c$, "setSpaceGroup", 
 function(doNormalize){
@@ -319,7 +319,7 @@ Clazz.overrideMethod(c$, "toSupercell",
 function(fpt){
 return this.unitCell.toSupercell(fpt);
 }, "JU.P3");
-Clazz.overrideMethod(c$, "toFractional", 
+Clazz.defineMethod(c$, "toFractional", 
 function(pt, ignoreOffset){
 if (!this.$isBio) this.unitCell.toFractional(pt, ignoreOffset);
 }, "JU.T3,~B");
@@ -685,7 +685,7 @@ var ops = this.getSymmetryOperations();
 return (ops == null || this.unitCell == null ? null : this.unitCell.getEquivalentPoints(pt, flags, ops,  new JU.Lst(), 0, 0, 0, this.getPeriodicity(), packing));
 }, "JU.Point3fi,~S,~N");
 Clazz.overrideMethod(c$, "getEquivPointList", 
-function(nInitial, flags, opsCtr, packing, pts){
+function(nInitial, flags, opsCtr, packing, pts, uc){
 var ops = (opsCtr == null ? this.getSymmetryOperations() : opsCtr);
 var newPt = (flags.indexOf("newpt") >= 0);
 var zapped = (flags.indexOf("zapped") >= 0);
@@ -714,9 +714,21 @@ this.unitCell.getEquivalentPoints(pts.get(i), flags, ops, pts, check0, n0, dup0,
 for (var i = n - nInitial; --i >= 0; ) pts.removeItemAt(nInitial);
 
 if (!tofractional) {
-for (var i = pts.size(); --i >= nInitial; ) this.toCartesian(pts.get(i), false);
-
-}}, "~N,~S,~A,~N,JU.Lst");
+var pt = (uc == null ? null :  new JU.P3());
+for (var i = pts.size(); --i >= nInitial; ) {
+var p = pts.get(i);
+this.toCartesian(p, false);
+if (uc != null) {
+uc.toFractional(pt.setP(p), false);
+if (!uc.isWithinUnitCell(pt, 1, 1, 1, packing)) {
+pts.removeItemAt(i);
+continue;
+}}}
+}}, "~N,~S,~A,~N,JU.Lst,J.api.SymmetryInterface");
+Clazz.overrideMethod(c$, "adjustRangeMinMax", 
+function(oabc, packingRange, minXYZ, maxXYZ, rmin, rmax, newMin, newMax){
+this.unitCell.adjustRangeMinMax(oabc, packingRange, minXYZ, maxXYZ, rmin, rmax, newMin, newMax);
+}, "~A,~N,JU.P3i,JU.P3i,JU.P3,JU.P3,JU.P3i,JU.P3i");
 Clazz.overrideMethod(c$, "getInvariantSymops", 
 function(pt, v0){
 var ops = this.getSymmetryOperations();
@@ -793,7 +805,7 @@ Clazz.overrideMethod(c$, "getTransform",
 function(fracA, fracB, best){
 return this.getDesc(null).getTransform(this.unitCell, this.getSymmetryOperations(), fracA, fracB, best);
 }, "JU.P3,JU.P3,~B");
-Clazz.overrideMethod(c$, "isWithinUnitCell", 
+Clazz.defineMethod(c$, "isWithinUnitCell", 
 function(pt, x, y, z, packing){
 return this.unitCell.isWithinUnitCell(x, y, z, packing, pt);
 }, "JU.P3,~N,~N,~N,~N");
@@ -1456,6 +1468,10 @@ Clazz.overrideMethod(c$, "getSpinSym",
 function(){
 return (this.spinSym == null ? this : this.spinSym);
 });
+Clazz.overrideMethod(c$, "updatePointGroup", 
+function(){
+return (this.pointGroup == null ? null : this.pointGroup.updateDraw());
+});
 c$.nullDesc = null;
 c$.aflowStructures = null;
 c$.itaData = null;
@@ -1482,4 +1498,4 @@ c$.wyckoffFinder = null;
 c$.clegInstance = null;
 c$.groupFactory = null;
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
