@@ -361,9 +361,8 @@ function(s){
 this.suvw = s;
 var v =  Clazz.newFloatArray (16, 0);
 JS.SymmetryOperation.getRotTransArrayAndXYZ(null, s, v, true, false, false, "uvw");
-var m4 = JU.M4.newA16(v);
 this.spinU =  new JU.M3();
-m4.getRotationScale(this.spinU);
+JU.M4.newA16(v).getRotationScale(this.spinU);
 this.timeReversal = Clazz.floatToInt(this.spinU.determinant3());
 this.suvwId = null;
 }, "~S");
@@ -483,7 +482,7 @@ var myLabels = JS.SymmetryOperation.getLabels(labels, (op == null || modDim == 0
 xyz = xyz.toLowerCase() + ",";
 xyz = xyz.$replace('(', ',');
 if (modDim > 0) xyz = JS.SymmetryOperation.replaceXn(xyz, modDim + 3);
-var xpt = 0;
+var xpt = -1;
 var tpt0 = 0;
 var rowPt = 0;
 var ch;
@@ -491,6 +490,7 @@ var iValue = 0;
 var denom = 0;
 var numer = 0;
 var itrans = 0;
+var itrans0 = 0;
 var decimalMultiplier = 1;
 var strT = "";
 var strOut = (retString ? "" : null);
@@ -511,8 +511,12 @@ case 45:
 case 43:
 isNegative = (ch == '-');
 signPt = i;
+if (iValue != 0) {
+if (xpt < 0) {
+itrans0 = iValue;
+} else {
 itrans = iValue;
-iValue = 0;
+}}iValue = 0;
 continue;
 case 47:
 denom = 0;
@@ -554,25 +558,26 @@ if (transPt > 0) {
 rotPt = i;
 i = transPt - 1;
 transPt = -i;
-iValue = itrans = 0;
+iValue = itrans = itrans0 = 0;
 denom = 0;
 continue;
 }transPt = i + 1;
 i = rotPt;
-} else if (itrans != 0) {
-iValue = itrans;
-itrans = 0;
+} else if (itrans != 0 || itrans0 != 0) {
+iValue = itrans + itrans0;
+itrans = itrans0 = 0;
 }iValue = JS.SymmetryOperation.normalizeTwelfths(iValue, denom == 0 ? 12 : divisor == 0 ? denom : divisor, doNormalize);
 if (linearRotTrans != null) linearRotTrans[tpt0 + nRows - 1] = (divisor == 0 && denom > 0 ? iValue = JS.SymmetryOperation.toDivisor(numer, denom) : iValue);
 if (strOut != null) {
 strT += JS.SymmetryOperation.xyzFraction12(iValue, (divisor == 0 ? denom : divisor), false, halfOrLess);
 strOut += (strOut === "" ? "" : ",") + strT;
 }if (rowPt == nRows - 2) return (retString ? strOut : "ok");
-iValue = itrans = 0;
+iValue = itrans = itrans0 = 0;
 numer = 0;
 denom = 0;
 strT = "";
 tpt0 += 4;
+xpt = -1;
 if (rowPt++ > 2 && modDim == 0) {
 JU.Logger.warn("Symmetry Operation? " + xyz);
 return null;
@@ -1399,6 +1404,7 @@ if ((this.opType & 8) == 0 && xyzList.indexOf(s) >= 0) {
 return false;
 }xyzList.append(s);
 this.spinU = opThis.spinU;
+this.suvw = opThis.suvw;
 this.timeReversal = opThis.timeReversal;
 lst.addLast(this);
 this.isFinalized = true;
@@ -1606,12 +1612,13 @@ matrix4 = JS.SymmetryOperation.stringToMatrix(xyz, labels);
 if (xyz.indexOf("u") >= 0) {
 matrix34 =  new JU.M3();
 matrix4.getRotationScale(matrix34);
-matrix4 = null;
 } else {
 matrix34 = matrix4;
 }} else if (Clazz.instanceOf(matrix34,"JU.M3")) {
 matrix4 =  new JU.M4();
 matrix4.setRotationScale(matrix34);
+} else {
+matrix4 = matrix34;
 }if ("rxyz".equals(labels)) {
 return JS.SymmetryOperation.matrixToRationalString(matrix34);
 }return (toMat ? matrix34 : JS.SymmetryOperation.getXYZFromMatrixFrac(matrix4, false, false, false, true, false, labels));
@@ -1620,6 +1627,12 @@ Clazz.defineMethod(c$, "toString",
 function(){
 return (this.rsvs == null ? Clazz.superCall(this, JS.SymmetryOperation, "toString", []) : Clazz.superCall(this, JS.SymmetryOperation, "toString", []) + " " + this.rsvs.toString());
 });
+Clazz.defineMethod(c$, "getSUVW", 
+function(){
+if (this.suvw == null && this.spinU != null) {
+this.suvw = JS.SymmetryOperation.getSpinString(this.spinU, true, false);
+}return this.suvw;
+});
 c$.atomTest = null;
 c$.twelfths =  Clazz.newArray(-1, ["0", "1/12", "1/6", "1/4", "1/3", "5/12", "1/2", "7/12", "2/3", "3/4", "5/6", "11/12"]);
 c$.labelsXYZ =  Clazz.newArray(-1, ["x", "y", "z"]);
@@ -1633,4 +1646,4 @@ c$.C3codes =  Clazz.newIntArray(-1, [0x031112, 0x121301, 0x130112, 0x021311, 0x1
 c$.xneg = null;
 c$.opPlanes = null;
 });
-;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:10:48 CST 2026
