@@ -946,7 +946,63 @@ Clazz.defineMethod(c$, "getMoreInfo",
 function(){
 return this.moreInfo;
 });
+c$.setSymmetryMinMax = Clazz.defineMethod(c$, "setSymmetryMinMax", 
+function(c, rmin, rmax){
+if (rmin.x > c.x) rmin.x = c.x;
+if (rmin.y > c.y) rmin.y = c.y;
+if (rmin.z > c.z) rmin.z = c.z;
+if (rmax.x < c.x) rmax.x = c.x;
+if (rmax.y < c.y) rmax.y = c.y;
+if (rmax.z < c.z) rmax.z = c.z;
+}, "JU.P3,JU.P3,JU.P3");
+Clazz.defineMethod(c$, "adjustRangeMinMax", 
+function(oabc, packingRange, minXYZ, maxXYZ, rmin, rmax, newMin, newMax){
+if (rmin == null) {
+rmin = JU.P3.new3(3.4028235E38, 3.4028235E38, 3.4028235E38);
+rmax = JU.P3.new3(-3.4028235E38, -3.4028235E38, -3.4028235E38);
+}var pa =  new JU.P3();
+var pb =  new JU.P3();
+var pc =  new JU.P3();
+if (!Float.isNaN(packingRange)) {
+pa.setT(oabc[1]);
+pb.setT(oabc[2]);
+pc.setT(oabc[3]);
+pa.scale(packingRange);
+pb.scale(packingRange);
+pc.scale(packingRange);
+}if (minXYZ != null) {
+oabc[0].scaleAdd2(minXYZ.x, oabc[1], oabc[0]);
+oabc[0].scaleAdd2(minXYZ.y, oabc[2], oabc[0]);
+oabc[0].scaleAdd2(minXYZ.z, oabc[3], oabc[0]);
+}oabc[0].sub(pa);
+oabc[0].sub(pb);
+oabc[0].sub(pc);
+var pt = JU.P3.newP(oabc[0]);
+this.toFractional(pt, true);
+JS.UnitCell.setSymmetryMinMax(pt, rmin, rmax);
+if (minXYZ != null) {
+oabc[1].scale(maxXYZ.x - minXYZ.x);
+oabc[2].scale(maxXYZ.y - minXYZ.y);
+oabc[3].scale(maxXYZ.z - minXYZ.z);
+}oabc[1].scaleAdd2(2, pa, oabc[1]);
+oabc[2].scaleAdd2(2, pb, oabc[2]);
+oabc[3].scaleAdd2(2, pc, oabc[3]);
+for (var i = 0; i < 3; i++) {
+for (var j = i + 1; j < 4; j++) {
+pt.add2(oabc[i], oabc[j]);
+if (i != 0) pt.add(oabc[0]);
+this.toFractional(pt, false);
+JS.UnitCell.setSymmetryMinMax(pt, rmin, rmax);
+}
+}
+this.toCartesian(pt, false);
+pt.add(oabc[1]);
+this.toFractional(pt, false);
+JS.UnitCell.setSymmetryMinMax(pt, rmin, rmax);
+newMin.set(Clazz.doubleToInt(Math.min(0, Math.floor(rmin.x + 0.001))), Clazz.doubleToInt(Math.min(0, Math.floor(rmin.y + 0.001))), Clazz.doubleToInt(Math.min(0, Math.floor(rmin.z + 0.001))));
+newMax.set(Clazz.doubleToInt(Math.max(1, Math.ceil(rmax.x - 0.001))), Clazz.doubleToInt(Math.max(1, Math.ceil(rmax.y - 0.001))), Clazz.doubleToInt(Math.max(1, Math.ceil(rmax.z - 0.001))));
+}, "~A,~N,JU.P3i,JU.P3i,JU.P3,JU.P3,JU.P3i,JU.P3i");
 c$.unitVectors =  Clazz.newArray(-1, [JV.JC.axisX, JV.JC.axisY, JV.JC.axisZ]);
 c$.v0 = null;
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 17:42:06 CST 2026
