@@ -1,3 +1,3 @@
 Clazz.declarePackage("JSV.api");
 Clazz.declareInterface(JSV.api, "JSVTreePath");
-;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
