@@ -647,4 +647,4 @@ c$.nmrdbServerH1New = "https://nmr-prediction.service.zakodium.com/v1/predict/pr
 c$.nmrdbServerC13New = "https://nmr-prediction.service.zakodium.com/v1/predict/carbon?POST?{\"molfile\":\"$MOLFILE\",\"includeJDX\":true}";
 c$.stringCount = 0;
 });
-;//5.0.1-v7 Thu Dec 18 09:19:10 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
