@@ -309,4 +309,4 @@ this.spectrumScaleFactor *= f;
 c$.NTICKS =  Clazz.newIntArray(-1, [2, 5, 10, 10]);
 c$.LOGTICKS =  Clazz.newDoubleArray(-1, [Math.log10(2), Math.log10(5), 0, 1]);
 });
-;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
