@@ -77,4 +77,4 @@ this.applyFromFields();
 });
 c$.posXY =  Clazz.newIntArray(-1, [-2147483648, 0]);
 });
-;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
