@@ -150,4 +150,4 @@ function(x){
 return (x == Math.floor(x) ? String.valueOf(Clazz.doubleToInt(x)) : JU.DF.formatDecimalTrimmed(x, 10));
 }, "~N");
 });
-;//5.0.1-v7 Thu Dec 18 09:19:10 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
