@@ -229,4 +229,4 @@ c$.unitCubePoints =  Clazz.newArray(-1, [JU.P3.new3(0, 0, 0), JU.P3.new3(0, 0, 1
 c$.toCanonical =  Clazz.newIntArray(-1, [0, 3, 4, 7, 1, 2, 5, 6]);
 c$.unitBboxPoints =  new Array(8);
 });
-;//5.0.1-v7 Wed Dec 31 09:23:37 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
