@@ -8,4 +8,4 @@ Clazz.defineEnumConstant(c$, "UTF_16LE", 3, []);
 Clazz.defineEnumConstant(c$, "UTF_32BE", 4, []);
 Clazz.defineEnumConstant(c$, "UTF_32LE", 5, []);
 });
-;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
