@@ -623,4 +623,4 @@ return  Clazz.newArray(-1, [pt_a_prime, n, r, JU.P3.new3(theta, pitch, residuesP
 }, "JU.P3,JU.P3,JU.Quat");
 c$.axisY = JU.V3.new3(0, 1, 0);
 });
-;//5.0.1-v7 Sat Jan 10 12:11:03 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:53:24 CST 2026
