@@ -178,4 +178,4 @@ return "[Modulation " + this.type + " " + JU.PT.toJSON(null, this.params) + "]";
 });
 c$.legendre =  Clazz.newArray(-1, [ Clazz.newDoubleArray(-1, [1]),  Clazz.newDoubleArray(-1, [0, 1])]);
 });
-;//5.0.1-v7 Sat Jan 10 12:43:18 CST 2026
+;//5.0.1-v7 Mon Jan 19 17:24:44 CST 2026
