@@ -42,4 +42,4 @@ this.z = p.z;
 this.i = p.i;
 }, "JU.Point3fi");
 });
-;//5.0.1-v7 Wed Dec 31 09:23:37 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
