@@ -105,14 +105,14 @@ rot.rotate(t);
 }}, "JU.M3,JU.M3,JU.M3,JU.T3");
 Clazz.defineMethod(c$, "rotateModelSpinVectors", 
 function(ms, modelIndex, rot, isdx){
-if (modelIndex < 0 || modelIndex >= ms.mc || ms.vibrations == null) return;
+if (modelIndex < 0 || modelIndex >= ms.mc || ms.vibrations == null) return -1;
 var vwr = ms.vwr;
 var m = ms.am[modelIndex];
 if (m.isJmolDataFrame) modelIndex = m.dataSourceFrame;
 var info = ms.getModelAuxiliaryInfo(modelIndex);
 if (rot == null) {
 rot = info.get("spinFrameRotationMatrix");
-if (rot == null) return;
+if (rot == null) return -1;
 }var noref = Double.isNaN(rot.getElement(0, 0));
 var isScreenZ = (noref && rot.getElement(2, 2) == 1);
 var deg = (noref || isScreenZ ? rot.getElement(1, 1) : 0);
@@ -154,7 +154,7 @@ matInv = this.matInv;
 matInv.setM3(mat);
 matInv.invert();
 }for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
-if (i >= ms.vibrations.length) return;
+if (i >= ms.vibrations.length) break;
 var v = ms.vibrations[i];
 if (v == null || !v.isFrom000 && v.magMoment == 0) continue;
 v.rotateSpin(matInv, rot, drot, ms.at[i]);
@@ -163,15 +163,26 @@ var quat = JU.Quat.newM(rot);
 var aa = quat.toAxisAngle4f();
 mat = JU.M3.newM3(rot);
 info.put("spinRotationMatrixApplied", mat);
+var jmolSpinModel = -1;
 for (var i = bsModels.nextSetBit(0); i >= 0; i = bsModels.nextSetBit(i + 1)) {
 m = ms.am[i];
 if (m.uvw0 != null) {
+jmolSpinModel = i;
 mat.rotate2(m.uvw0[0], m.uvw[0]);
 mat.rotate2(m.uvw0[1], m.uvw[1]);
 mat.rotate2(m.uvw0[2], m.uvw[2]);
 }}
 info.put("spinRotationAxisAngleApplied", aa);
 if (ms.unitCells[modelIndex] != null) ms.unitCells[modelIndex].setSpinAxisAngle(aa);
+return jmolSpinModel;
 }, "JM.ModelSet,~N,JU.M3,~B");
+c$.find = Clazz.defineMethod(c$, "find", 
+function(modelSet, bs, v0){
+if (v0 != null) for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
+var v = modelSet.getVibration(i, false);
+if (v != null && v.distance(v0) < 0.1) return modelSet.at[i];
+}
+return null;
+}, "JM.ModelSet,JU.BS,JU.Vibration");
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Mon Jan 19 20:51:34 CST 2026
