@@ -16,6 +16,7 @@ this.appletProxy = null;
 this.cache = null;
 this.pngjCache = null;
 this.spardirCache = null;
+this.staticJmolDataReader = null;
 Clazz.instantialize(this, arguments);}, JV, "FileManager", null, javajs.api.BytePoster);
 Clazz.prepareFields (c$, function(){
 this.cache =  new java.util.Hashtable();
@@ -80,7 +81,7 @@ return this.lastFileType;
 });
 Clazz.defineMethod(c$, "setFileType", 
 function(fileType){
-this.lastFileType = fileType;
+if (!"JmolData".equals(fileType)) this.lastFileType = fileType;
 }, "~S");
 Clazz.defineMethod(c$, "getFileName", 
 function(){
@@ -112,9 +113,8 @@ function(name, htParams, isAppend){
 if (htParams.get("atomDataOnly") == null) this.setLoadState(htParams);
 var name0 = name;
 var pt = name.indexOf("::");
-if (pt < 0) {
-name = this.vwr.resolveDatabaseFormat(name);
-}if (!name0.equals(name) && name0.indexOf("/") < 0 && JV.Viewer.hasDatabasePrefix(name0)) {
+if (pt < 0) name = this.vwr.resolveDatabaseFormat(name);
+if (!name0.equals(name) && name0.indexOf("/") < 0 && JV.Viewer.hasDatabasePrefix(name0)) {
 htParams.put("dbName", name0);
 }if (name.endsWith("%2D%")) {
 var filter = htParams.get("filter");
@@ -127,6 +127,7 @@ var names = this.getClassifiedName(nameAsGiven, true);
 if (names.length == 1) return names[0];
 var fullPathName = names[0];
 var fileName = names[1];
+this.setFileType(fileType);
 htParams.put("fullPathName", (fileType == null ? "" : fileType + "::") + JV.FileManager.fixDOSName(fullPathName));
 if (this.vwr.getBoolean(603979879) && this.vwr.getBoolean(603979825)) this.vwr.getChimeMessenger().update(fullPathName);
 var fileReader =  new J.io.FileReader(this.vwr, fileName, fullPathName, nameAsGiven, fileType, null, htParams, isAppend);
@@ -558,7 +559,7 @@ names[1] = JV.FileManager.stripPath(names[0]);
 return names;
 }name = this.vwr.resolveDatabaseFormat(name);
 if (name == null) return  Clazz.newArray(-1, [null]);
-if (name.indexOf(":") < 0 && name.indexOf('/') != 0 && name.indexOf('\\') != 0) if (name.startsWith("file:///") && name.indexOf('|') == 9) name = name.substring(0, 9) + ':' + name.substring(10);
+if (name.startsWith("file:///") && name.indexOf('|') == 9) name = name.substring(0, 9) + ':' + name.substring(10);
 if (name.indexOf(":") < 0 && name.indexOf('/') != 0 && name.indexOf('\\') != 0) name = JV.FileManager.addDirectory(this.vwr.getDefaultDirectory(), name);
 if (this.appletDocumentBaseURL == null) {
 if (JU.OC.urlTypeIndex(name) >= 0 || this.vwr.haveAccess(JV.Viewer.ACCESS.NONE) || this.vwr.haveAccess(JV.Viewer.ACCESS.READSPT) && !name.endsWith(".spt") && !name.endsWith("/") || !this.vwr.haveAccessInternal(name)) {
@@ -1015,11 +1016,12 @@ return this.vwr.getJzt().isZipStream(br);
 }, "~O");
 Clazz.defineMethod(c$, "getJmolDataReader", 
 function(){
-if (JV.FileManager.staticJmolDataReader == null) JV.FileManager.staticJmolDataReader = J.adapter.smarter.Resolver.getReader("JmolData", null);
-return JV.FileManager.staticJmolDataReader;
+if (this.staticJmolDataReader == null) {
+this.staticJmolDataReader = J.adapter.smarter.Resolver.getReader("JmolData", null);
+this.staticJmolDataReader.vwr = this.vwr;
+}return this.staticJmolDataReader;
 });
 c$.SIMULATION_PROTOCOL = "http://SIMULATION/";
 c$.scriptFilePrefixes =  Clazz.newArray(-1, ["/*file*/\"", "FILE0=\"", "FILE1=\""]);
-c$.staticJmolDataReader = null;
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
