@@ -294,6 +294,7 @@ var vibsOn = (vibrationVectors != null && tm.vibrationOn);
 var checkOccupancy = (this.ms.bsModulated != null && this.ms.occupancies != null);
 var atoms = this.ms.at;
 var occ;
+var occMax = vwr.getInt(553648159);
 var haveMods = false;
 var bsSlabbed = this.bsSlabbedInternal;
 bsSlabbed.clearAll();
@@ -311,7 +312,7 @@ atom.sD = Clazz.floatToInt(vwr.tm.scaleToScreen(screen.z, d));
 if (checkOccupancy && vibrationVectors[i] != null && (occ = vibrationVectors[i].getOccupancy100(vibsOn)) != -2147483648) {
 haveMods = true;
 atom.setShapeVisibility(2, false);
-if (occ >= 0 && occ < 50) atom.setShapeVisibility(24, false);
+if (occ >= 0 && occ < occMax) atom.setShapeVisibility(24, false);
  else atom.setShapeVisibility(8 | (atom.madAtom > 0 ? 16 : 0), true);
 this.ms.occupancies[atom.i] = Math.abs(occ);
 }}
@@ -404,4 +405,4 @@ this.vwr.selectStatus(bsSelected, false, 0, true, false);
 c$.hoverable =  Clazz.newIntArray(-1, [31, 20, 25, 24, 22, 36]);
 c$.clickableMax = JV.ShapeManager.hoverable.length - 1;
 });
-;//5.0.1-v7 Sat Jan 10 12:50:42 CST 2026
+;//5.0.1-v7 Tue Jan 27 21:12:09 CST 2026
