@@ -105,4 +105,4 @@ fScrPt.z += this.zOffset;
 this.matrixTransform.rotTrans2(ptXYZ, fScrPt);
 }}, "JU.T3,JU.P3");
 });
-;//5.0.1-v7 Wed Dec 31 09:09:50 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
