@@ -235,4 +235,4 @@ function(vwr, name){
 return J.api.Interface.getInterface("JV.binding." + name + "Binding", vwr, "script");
 }, "JV.Viewer,~S");
 });
-;//5.0.1-v7 Sat Jan 10 12:35:15 CST 2026
+;//5.0.1-v7 Mon Jan 19 16:49:55 CST 2026
