@@ -452,7 +452,7 @@ return f * JU.BC.fracIEEE[i + 140];
 }, "~N,~N");
 c$.fracIEEE = null;
 })();
-;//5.0.1-v7 Thu Dec 18 09:19:10 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
 Clazz_declarePackage("JU");
 Clazz_load(["javajs.api.GenericBinaryDocument", "JU.BC"], "JU.BinaryDocument", ["java.io.DataInputStream"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -678,7 +678,7 @@ function(b){
 this.isBigEndian = b;
 }, "~B");
 });
-;//5.0.1-v7 Thu Dec 18 09:19:10 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
 })(Clazz
 ,Clazz.getClassName
 ,Clazz.newLongArray
