@@ -1,3 +1,3 @@
 Clazz.declarePackage("javajs.api");
 Clazz.declareInterface(javajs.api, "GenericImageEncoder");
-;//5.0.1-v7 Thu Dec 18 09:19:10 CST 2025
+;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
